// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_OPERAND_CONST_CAN_USE_PC_CMP_A32_H_
#define VIXL_ASSEMBLER_COND_RD_OPERAND_CONST_CAN_USE_PC_CMP_A32_H_

const byte kInstruction_cmp_ls_r10_0x00ab0000[] = {
  0xab, 0x08, 0x5a, 0x93 // cmp ls r10 0x00ab0000
};
const byte kInstruction_cmp_ls_r13_0xf000000f[] = {
  0xff, 0x02, 0x5d, 0x93 // cmp ls r13 0xf000000f
};
const byte kInstruction_cmp_pl_r4_0x00003fc0[] = {
  0xff, 0x0d, 0x54, 0x53 // cmp pl r4 0x00003fc0
};
const byte kInstruction_cmp_ne_r15_0x00ab0000[] = {
  0xab, 0x08, 0x5f, 0x13 // cmp ne r15 0x00ab0000
};
const byte kInstruction_cmp_lt_r14_0x002ac000[] = {
  0xab, 0x09, 0x5e, 0xb3 // cmp lt r14 0x002ac000
};
const byte kInstruction_cmp_eq_r15_0x000000ab[] = {
  0xab, 0x00, 0x5f, 0x03 // cmp eq r15 0x000000ab
};
const byte kInstruction_cmp_al_r6_0x002ac000[] = {
  0xab, 0x09, 0x56, 0xe3 // cmp al r6 0x002ac000
};
const byte kInstruction_cmp_pl_r2_0x0002ac00[] = {
  0xab, 0x0b, 0x52, 0x53 // cmp pl r2 0x0002ac00
};
const byte kInstruction_cmp_mi_r8_0x00000000[] = {
  0x00, 0x00, 0x58, 0x43 // cmp mi r8 0x00000000
};
const byte kInstruction_cmp_pl_r13_0x02ac0000[] = {
  0xab, 0x07, 0x5d, 0x53 // cmp pl r13 0x02ac0000
};
const byte kInstruction_cmp_ge_r9_0xac000002[] = {
  0xab, 0x03, 0x59, 0xa3 // cmp ge r9 0xac000002
};
const byte kInstruction_cmp_ne_r3_0x000003fc[] = {
  0xff, 0x0f, 0x53, 0x13 // cmp ne r3 0x000003fc
};
const byte kInstruction_cmp_pl_r10_0xf000000f[] = {
  0xff, 0x02, 0x5a, 0x53 // cmp pl r10 0xf000000f
};
const byte kInstruction_cmp_cc_r0_0x00003fc0[] = {
  0xff, 0x0d, 0x50, 0x33 // cmp cc r0 0x00003fc0
};
const byte kInstruction_cmp_gt_r6_0x002ac000[] = {
  0xab, 0x09, 0x56, 0xc3 // cmp gt r6 0x002ac000
};
const byte kInstruction_cmp_cs_r1_0x00ff0000[] = {
  0xff, 0x08, 0x51, 0x23 // cmp cs r1 0x00ff0000
};
const byte kInstruction_cmp_lt_r8_0x000002ac[] = {
  0xab, 0x0f, 0x58, 0xb3 // cmp lt r8 0x000002ac
};
const byte kInstruction_cmp_vc_r4_0x2ac00000[] = {
  0xab, 0x05, 0x54, 0x73 // cmp vc r4 0x2ac00000
};
const byte kInstruction_cmp_al_r11_0x00003fc0[] = {
  0xff, 0x0d, 0x5b, 0xe3 // cmp al r11 0x00003fc0
};
const byte kInstruction_cmp_lt_r9_0x000000ab[] = {
  0xab, 0x00, 0x59, 0xb3 // cmp lt r9 0x000000ab
};
const byte kInstruction_cmp_le_r15_0x0000ff00[] = {
  0xff, 0x0c, 0x5f, 0xd3 // cmp le r15 0x0000ff00
};
const byte kInstruction_cmp_vc_r9_0xff000000[] = {
  0xff, 0x04, 0x59, 0x73 // cmp vc r9 0xff000000
};
const byte kInstruction_cmp_ge_r0_0x0ff00000[] = {
  0xff, 0x06, 0x50, 0xa3 // cmp ge r0 0x0ff00000
};
const byte kInstruction_cmp_vc_r1_0x00ff0000[] = {
  0xff, 0x08, 0x51, 0x73 // cmp vc r1 0x00ff0000
};
const byte kInstruction_cmp_vs_r12_0x00000ff0[] = {
  0xff, 0x0e, 0x5c, 0x63 // cmp vs r12 0x00000ff0
};
const byte kInstruction_cmp_pl_r13_0x003fc000[] = {
  0xff, 0x09, 0x5d, 0x53 // cmp pl r13 0x003fc000
};
const byte kInstruction_cmp_eq_r4_0xff000000[] = {
  0xff, 0x04, 0x54, 0x03 // cmp eq r4 0xff000000
};
const byte kInstruction_cmp_eq_r12_0xac000002[] = {
  0xab, 0x03, 0x5c, 0x03 // cmp eq r12 0xac000002
};
const byte kInstruction_cmp_al_r11_0x000000ab[] = {
  0xab, 0x00, 0x5b, 0xe3 // cmp al r11 0x000000ab
};
const byte kInstruction_cmp_ge_r10_0x00ff0000[] = {
  0xff, 0x08, 0x5a, 0xa3 // cmp ge r10 0x00ff0000
};
const byte kInstruction_cmp_vs_r7_0x0002ac00[] = {
  0xab, 0x0b, 0x57, 0x63 // cmp vs r7 0x0002ac00
};
const byte kInstruction_cmp_le_r7_0x002ac000[] = {
  0xab, 0x09, 0x57, 0xd3 // cmp le r7 0x002ac000
};
const byte kInstruction_cmp_vc_r9_0x000003fc[] = {
  0xff, 0x0f, 0x59, 0x73 // cmp vc r9 0x000003fc
};
const byte kInstruction_cmp_vs_r14_0x002ac000[] = {
  0xab, 0x09, 0x5e, 0x63 // cmp vs r14 0x002ac000
};
const byte kInstruction_cmp_vs_r1_0x000003fc[] = {
  0xff, 0x0f, 0x51, 0x63 // cmp vs r1 0x000003fc
};
const byte kInstruction_cmp_le_r13_0x3fc00000[] = {
  0xff, 0x05, 0x5d, 0xd3 // cmp le r13 0x3fc00000
};
const byte kInstruction_cmp_ne_r9_0x0002ac00[] = {
  0xab, 0x0b, 0x59, 0x13 // cmp ne r9 0x0002ac00
};
const byte kInstruction_cmp_al_r0_0x00ab0000[] = {
  0xab, 0x08, 0x50, 0xe3 // cmp al r0 0x00ab0000
};
const byte kInstruction_cmp_hi_r5_0xff000000[] = {
  0xff, 0x04, 0x55, 0x83 // cmp hi r5 0xff000000
};
const byte kInstruction_cmp_hi_r14_0x000000ab[] = {
  0xab, 0x00, 0x5e, 0x83 // cmp hi r14 0x000000ab
};
const byte kInstruction_cmp_hi_r14_0x000003fc[] = {
  0xff, 0x0f, 0x5e, 0x83 // cmp hi r14 0x000003fc
};
const byte kInstruction_cmp_mi_r14_0x03fc0000[] = {
  0xff, 0x07, 0x5e, 0x43 // cmp mi r14 0x03fc0000
};
const byte kInstruction_cmp_mi_r8_0x000000ff[] = {
  0xff, 0x00, 0x58, 0x43 // cmp mi r8 0x000000ff
};
const byte kInstruction_cmp_gt_r6_0x000ab000[] = {
  0xab, 0x0a, 0x56, 0xc3 // cmp gt r6 0x000ab000
};
const byte kInstruction_cmp_mi_r12_0x0ff00000[] = {
  0xff, 0x06, 0x5c, 0x43 // cmp mi r12 0x0ff00000
};
const byte kInstruction_cmp_vs_r3_0xff000000[] = {
  0xff, 0x04, 0x53, 0x63 // cmp vs r3 0xff000000
};
const byte kInstruction_cmp_vc_r7_0x00ab0000[] = {
  0xab, 0x08, 0x57, 0x73 // cmp vc r7 0x00ab0000
};
const byte kInstruction_cmp_hi_r6_0x03fc0000[] = {
  0xff, 0x07, 0x56, 0x83 // cmp hi r6 0x03fc0000
};
const byte kInstruction_cmp_ls_r5_0x00ab0000[] = {
  0xab, 0x08, 0x55, 0x93 // cmp ls r5 0x00ab0000
};
const byte kInstruction_cmp_ls_r4_0x000002ac[] = {
  0xab, 0x0f, 0x54, 0x93 // cmp ls r4 0x000002ac
};
const byte kInstruction_cmp_le_r13_0x03fc0000[] = {
  0xff, 0x07, 0x5d, 0xd3 // cmp le r13 0x03fc0000
};
const byte kInstruction_cmp_le_r15_0x002ac000[] = {
  0xab, 0x09, 0x5f, 0xd3 // cmp le r15 0x002ac000
};
const byte kInstruction_cmp_pl_r6_0xff000000[] = {
  0xff, 0x04, 0x56, 0x53 // cmp pl r6 0xff000000
};
const byte kInstruction_cmp_gt_r7_0x00000ab0[] = {
  0xab, 0x0e, 0x57, 0xc3 // cmp gt r7 0x00000ab0
};
const byte kInstruction_cmp_hi_r3_0x2ac00000[] = {
  0xab, 0x05, 0x53, 0x83 // cmp hi r3 0x2ac00000
};
const byte kInstruction_cmp_gt_r15_0x00000000[] = {
  0x00, 0x00, 0x5f, 0xc3 // cmp gt r15 0x00000000
};
const byte kInstruction_cmp_gt_r1_0x002ac000[] = {
  0xab, 0x09, 0x51, 0xc3 // cmp gt r1 0x002ac000
};
const byte kInstruction_cmp_hi_r2_0x0000ff00[] = {
  0xff, 0x0c, 0x52, 0x83 // cmp hi r2 0x0000ff00
};
const byte kInstruction_cmp_pl_r10_0x03fc0000[] = {
  0xff, 0x07, 0x5a, 0x53 // cmp pl r10 0x03fc0000
};
const byte kInstruction_cmp_gt_r10_0xb000000a[] = {
  0xab, 0x02, 0x5a, 0xc3 // cmp gt r10 0xb000000a
};
const byte kInstruction_cmp_ge_r10_0x002ac000[] = {
  0xab, 0x09, 0x5a, 0xa3 // cmp ge r10 0x002ac000
};
const byte kInstruction_cmp_al_r4_0x0ab00000[] = {
  0xab, 0x06, 0x54, 0xe3 // cmp al r4 0x0ab00000
};
const byte kInstruction_cmp_ne_r12_0x00000000[] = {
  0x00, 0x00, 0x5c, 0x13 // cmp ne r12 0x00000000
};
const byte kInstruction_cmp_cs_r5_0x00003fc0[] = {
  0xff, 0x0d, 0x55, 0x23 // cmp cs r5 0x00003fc0
};
const byte kInstruction_cmp_cc_r6_0x000000ff[] = {
  0xff, 0x00, 0x56, 0x33 // cmp cc r6 0x000000ff
};
const byte kInstruction_cmp_hi_r14_0x03fc0000[] = {
  0xff, 0x07, 0x5e, 0x83 // cmp hi r14 0x03fc0000
};
const byte kInstruction_cmp_hi_r3_0xab000000[] = {
  0xab, 0x04, 0x53, 0x83 // cmp hi r3 0xab000000
};
const byte kInstruction_cmp_lt_r2_0x000ff000[] = {
  0xff, 0x0a, 0x52, 0xb3 // cmp lt r2 0x000ff000
};
const byte kInstruction_cmp_gt_r3_0x00ff0000[] = {
  0xff, 0x08, 0x53, 0xc3 // cmp gt r3 0x00ff0000
};
const byte kInstruction_cmp_le_r14_0x0ab00000[] = {
  0xab, 0x06, 0x5e, 0xd3 // cmp le r14 0x0ab00000
};
const byte kInstruction_cmp_cc_r13_0x03fc0000[] = {
  0xff, 0x07, 0x5d, 0x33 // cmp cc r13 0x03fc0000
};
const byte kInstruction_cmp_gt_r6_0xb000000a[] = {
  0xab, 0x02, 0x56, 0xc3 // cmp gt r6 0xb000000a
};
const byte kInstruction_cmp_pl_r3_0x2ac00000[] = {
  0xab, 0x05, 0x53, 0x53 // cmp pl r3 0x2ac00000
};
const byte kInstruction_cmp_mi_r15_0x000000ff[] = {
  0xff, 0x00, 0x5f, 0x43 // cmp mi r15 0x000000ff
};
const byte kInstruction_cmp_gt_r4_0x00000ff0[] = {
  0xff, 0x0e, 0x54, 0xc3 // cmp gt r4 0x00000ff0
};
const byte kInstruction_cmp_ne_r4_0x000003fc[] = {
  0xff, 0x0f, 0x54, 0x13 // cmp ne r4 0x000003fc
};
const byte kInstruction_cmp_ne_r5_0x00ff0000[] = {
  0xff, 0x08, 0x55, 0x13 // cmp ne r5 0x00ff0000
};
const byte kInstruction_cmp_ge_r7_0x000003fc[] = {
  0xff, 0x0f, 0x57, 0xa3 // cmp ge r7 0x000003fc
};
const byte kInstruction_cmp_vs_r5_0x00000000[] = {
  0x00, 0x00, 0x55, 0x63 // cmp vs r5 0x00000000
};
const byte kInstruction_cmp_vs_r6_0x2ac00000[] = {
  0xab, 0x05, 0x56, 0x63 // cmp vs r6 0x2ac00000
};
const byte kInstruction_cmp_mi_r1_0x3fc00000[] = {
  0xff, 0x05, 0x51, 0x43 // cmp mi r1 0x3fc00000
};
const byte kInstruction_cmp_gt_r8_0xc000002a[] = {
  0xab, 0x01, 0x58, 0xc3 // cmp gt r8 0xc000002a
};
const byte kInstruction_cmp_pl_r10_0x000000ab[] = {
  0xab, 0x00, 0x5a, 0x53 // cmp pl r10 0x000000ab
};
const byte kInstruction_cmp_mi_r6_0xab000000[] = {
  0xab, 0x04, 0x56, 0x43 // cmp mi r6 0xab000000
};
const byte kInstruction_cmp_ls_r12_0x3fc00000[] = {
  0xff, 0x05, 0x5c, 0x93 // cmp ls r12 0x3fc00000
};
const byte kInstruction_cmp_vs_r13_0x03fc0000[] = {
  0xff, 0x07, 0x5d, 0x63 // cmp vs r13 0x03fc0000
};
const byte kInstruction_cmp_eq_r8_0x00000ab0[] = {
  0xab, 0x0e, 0x58, 0x03 // cmp eq r8 0x00000ab0
};
const byte kInstruction_cmp_gt_r6_0x000000ff[] = {
  0xff, 0x00, 0x56, 0xc3 // cmp gt r6 0x000000ff
};
const byte kInstruction_cmp_vs_r5_0x000ab000[] = {
  0xab, 0x0a, 0x55, 0x63 // cmp vs r5 0x000ab000
};
const byte kInstruction_cmp_mi_r1_0x2ac00000[] = {
  0xab, 0x05, 0x51, 0x43 // cmp mi r1 0x2ac00000
};
const byte kInstruction_cmp_vs_r6_0x00003fc0[] = {
  0xff, 0x0d, 0x56, 0x63 // cmp vs r6 0x00003fc0
};
const byte kInstruction_cmp_gt_r6_0x000002ac[] = {
  0xab, 0x0f, 0x56, 0xc3 // cmp gt r6 0x000002ac
};
const byte kInstruction_cmp_eq_r2_0x00000000[] = {
  0x00, 0x00, 0x52, 0x03 // cmp eq r2 0x00000000
};
const byte kInstruction_cmp_eq_r10_0xc000003f[] = {
  0xff, 0x01, 0x5a, 0x03 // cmp eq r10 0xc000003f
};
const byte kInstruction_cmp_mi_r7_0x00ab0000[] = {
  0xab, 0x08, 0x57, 0x43 // cmp mi r7 0x00ab0000
};
const byte kInstruction_cmp_cc_r7_0x2ac00000[] = {
  0xab, 0x05, 0x57, 0x33 // cmp cc r7 0x2ac00000
};
const byte kInstruction_cmp_pl_r4_0x00ab0000[] = {
  0xab, 0x08, 0x54, 0x53 // cmp pl r4 0x00ab0000
};
const byte kInstruction_cmp_ne_r15_0x00000ff0[] = {
  0xff, 0x0e, 0x5f, 0x13 // cmp ne r15 0x00000ff0
};
const byte kInstruction_cmp_al_r6_0x02ac0000[] = {
  0xab, 0x07, 0x56, 0xe3 // cmp al r6 0x02ac0000
};
const byte kInstruction_cmp_pl_r6_0x000002ac[] = {
  0xab, 0x0f, 0x56, 0x53 // cmp pl r6 0x000002ac
};
const byte kInstruction_cmp_ne_r14_0x00ff0000[] = {
  0xff, 0x08, 0x5e, 0x13 // cmp ne r14 0x00ff0000
};
const byte kInstruction_cmp_ne_r5_0x0003fc00[] = {
  0xff, 0x0b, 0x55, 0x13 // cmp ne r5 0x0003fc00
};
const byte kInstruction_cmp_pl_r6_0x00000ab0[] = {
  0xab, 0x0e, 0x56, 0x53 // cmp pl r6 0x00000ab0
};
const byte kInstruction_cmp_eq_r10_0x00002ac0[] = {
  0xab, 0x0d, 0x5a, 0x03 // cmp eq r10 0x00002ac0
};
const byte kInstruction_cmp_mi_r4_0x00000ab0[] = {
  0xab, 0x0e, 0x54, 0x43 // cmp mi r4 0x00000ab0
};
const byte kInstruction_cmp_vc_r5_0x000ab000[] = {
  0xab, 0x0a, 0x55, 0x73 // cmp vc r5 0x000ab000
};
const byte kInstruction_cmp_ge_r0_0x02ac0000[] = {
  0xab, 0x07, 0x50, 0xa3 // cmp ge r0 0x02ac0000
};
const byte kInstruction_cmp_pl_r5_0x000002ac[] = {
  0xab, 0x0f, 0x55, 0x53 // cmp pl r5 0x000002ac
};
const byte kInstruction_cmp_ge_r13_0x00000ab0[] = {
  0xab, 0x0e, 0x5d, 0xa3 // cmp ge r13 0x00000ab0
};
const byte kInstruction_cmp_eq_r2_0x03fc0000[] = {
  0xff, 0x07, 0x52, 0x03 // cmp eq r2 0x03fc0000
};
const byte kInstruction_cmp_lt_r11_0x00000ab0[] = {
  0xab, 0x0e, 0x5b, 0xb3 // cmp lt r11 0x00000ab0
};
const byte kInstruction_cmp_ge_r6_0x00000000[] = {
  0x00, 0x00, 0x56, 0xa3 // cmp ge r6 0x00000000
};
const byte kInstruction_cmp_gt_r2_0xac000002[] = {
  0xab, 0x03, 0x52, 0xc3 // cmp gt r2 0xac000002
};
const byte kInstruction_cmp_le_r15_0x000000ab[] = {
  0xab, 0x00, 0x5f, 0xd3 // cmp le r15 0x000000ab
};
const byte kInstruction_cmp_cc_r4_0x00000ff0[] = {
  0xff, 0x0e, 0x54, 0x33 // cmp cc r4 0x00000ff0
};
const byte kInstruction_cmp_pl_r10_0x02ac0000[] = {
  0xab, 0x07, 0x5a, 0x53 // cmp pl r10 0x02ac0000
};
const byte kInstruction_cmp_gt_r9_0x00000000[] = {
  0x00, 0x00, 0x59, 0xc3 // cmp gt r9 0x00000000
};
const byte kInstruction_cmp_vs_r8_0x000000ff[] = {
  0xff, 0x00, 0x58, 0x63 // cmp vs r8 0x000000ff
};
const byte kInstruction_cmp_gt_r14_0x0002ac00[] = {
  0xab, 0x0b, 0x5e, 0xc3 // cmp gt r14 0x0002ac00
};
const byte kInstruction_cmp_vs_r14_0x00002ac0[] = {
  0xab, 0x0d, 0x5e, 0x63 // cmp vs r14 0x00002ac0
};
const byte kInstruction_cmp_ge_r12_0x00000000[] = {
  0x00, 0x00, 0x5c, 0xa3 // cmp ge r12 0x00000000
};
const byte kInstruction_cmp_vc_r8_0xf000000f[] = {
  0xff, 0x02, 0x58, 0x73 // cmp vc r8 0xf000000f
};
const byte kInstruction_cmp_cs_r6_0x00003fc0[] = {
  0xff, 0x0d, 0x56, 0x23 // cmp cs r6 0x00003fc0
};
const byte kInstruction_cmp_le_r4_0x000003fc[] = {
  0xff, 0x0f, 0x54, 0xd3 // cmp le r4 0x000003fc
};
const byte kInstruction_cmp_cs_r5_0x000ff000[] = {
  0xff, 0x0a, 0x55, 0x23 // cmp cs r5 0x000ff000
};
const byte kInstruction_cmp_eq_r2_0x0000ff00[] = {
  0xff, 0x0c, 0x52, 0x03 // cmp eq r2 0x0000ff00
};
const byte kInstruction_cmp_pl_r10_0x0ab00000[] = {
  0xab, 0x06, 0x5a, 0x53 // cmp pl r10 0x0ab00000
};
const byte kInstruction_cmp_le_r11_0xac000002[] = {
  0xab, 0x03, 0x5b, 0xd3 // cmp le r11 0xac000002
};
const byte kInstruction_cmp_vs_r15_0x00003fc0[] = {
  0xff, 0x0d, 0x5f, 0x63 // cmp vs r15 0x00003fc0
};
const byte kInstruction_cmp_lt_r2_0x0002ac00[] = {
  0xab, 0x0b, 0x52, 0xb3 // cmp lt r2 0x0002ac00
};
const byte kInstruction_cmp_eq_r1_0x00ab0000[] = {
  0xab, 0x08, 0x51, 0x03 // cmp eq r1 0x00ab0000
};
const byte kInstruction_cmp_cc_r7_0x03fc0000[] = {
  0xff, 0x07, 0x57, 0x33 // cmp cc r7 0x03fc0000
};
const byte kInstruction_cmp_mi_r6_0x00000ab0[] = {
  0xab, 0x0e, 0x56, 0x43 // cmp mi r6 0x00000ab0
};
const byte kInstruction_cmp_eq_r4_0x00000ab0[] = {
  0xab, 0x0e, 0x54, 0x03 // cmp eq r4 0x00000ab0
};
const byte kInstruction_cmp_ls_r3_0x0003fc00[] = {
  0xff, 0x0b, 0x53, 0x93 // cmp ls r3 0x0003fc00
};
const byte kInstruction_cmp_mi_r6_0x000ab000[] = {
  0xab, 0x0a, 0x56, 0x43 // cmp mi r6 0x000ab000
};
const byte kInstruction_cmp_ne_r12_0x003fc000[] = {
  0xff, 0x09, 0x5c, 0x13 // cmp ne r12 0x003fc000
};
const byte kInstruction_cmp_eq_r11_0x00ff0000[] = {
  0xff, 0x08, 0x5b, 0x03 // cmp eq r11 0x00ff0000
};
const byte kInstruction_cmp_cs_r13_0x00ab0000[] = {
  0xab, 0x08, 0x5d, 0x23 // cmp cs r13 0x00ab0000
};
const byte kInstruction_cmp_eq_r5_0x000003fc[] = {
  0xff, 0x0f, 0x55, 0x03 // cmp eq r5 0x000003fc
};
const byte kInstruction_cmp_vs_r6_0x0003fc00[] = {
  0xff, 0x0b, 0x56, 0x63 // cmp vs r6 0x0003fc00
};
const byte kInstruction_cmp_pl_r8_0x0ff00000[] = {
  0xff, 0x06, 0x58, 0x53 // cmp pl r8 0x0ff00000
};
const byte kInstruction_cmp_pl_r11_0x0000ab00[] = {
  0xab, 0x0c, 0x5b, 0x53 // cmp pl r11 0x0000ab00
};
const byte kInstruction_cmp_le_r2_0xac000002[] = {
  0xab, 0x03, 0x52, 0xd3 // cmp le r2 0xac000002
};
const byte kInstruction_cmp_vc_r10_0x000ff000[] = {
  0xff, 0x0a, 0x5a, 0x73 // cmp vc r10 0x000ff000
};
const byte kInstruction_cmp_le_r4_0x00000ff0[] = {
  0xff, 0x0e, 0x54, 0xd3 // cmp le r4 0x00000ff0
};
const byte kInstruction_cmp_gt_r12_0x00000ff0[] = {
  0xff, 0x0e, 0x5c, 0xc3 // cmp gt r12 0x00000ff0
};
const byte kInstruction_cmp_le_r5_0x0002ac00[] = {
  0xab, 0x0b, 0x55, 0xd3 // cmp le r5 0x0002ac00
};
const byte kInstruction_cmp_le_r0_0xac000002[] = {
  0xab, 0x03, 0x50, 0xd3 // cmp le r0 0xac000002
};
const byte kInstruction_cmp_vs_r11_0x0ff00000[] = {
  0xff, 0x06, 0x5b, 0x63 // cmp vs r11 0x0ff00000
};
const byte kInstruction_cmp_ls_r0_0x000ab000[] = {
  0xab, 0x0a, 0x50, 0x93 // cmp ls r0 0x000ab000
};
const byte kInstruction_cmp_ls_r2_0xf000000f[] = {
  0xff, 0x02, 0x52, 0x93 // cmp ls r2 0xf000000f
};
const byte kInstruction_cmp_cs_r3_0x0ff00000[] = {
  0xff, 0x06, 0x53, 0x23 // cmp cs r3 0x0ff00000
};
const byte kInstruction_cmp_hi_r8_0x0ff00000[] = {
  0xff, 0x06, 0x58, 0x83 // cmp hi r8 0x0ff00000
};
const byte kInstruction_cmp_gt_r3_0x00002ac0[] = {
  0xab, 0x0d, 0x53, 0xc3 // cmp gt r3 0x00002ac0
};
const byte kInstruction_cmp_al_r15_0xab000000[] = {
  0xab, 0x04, 0x5f, 0xe3 // cmp al r15 0xab000000
};
const byte kInstruction_cmp_eq_r13_0x000000ab[] = {
  0xab, 0x00, 0x5d, 0x03 // cmp eq r13 0x000000ab
};
const byte kInstruction_cmp_al_r2_0xc000002a[] = {
  0xab, 0x01, 0x52, 0xe3 // cmp al r2 0xc000002a
};
const byte kInstruction_cmp_eq_r13_0x03fc0000[] = {
  0xff, 0x07, 0x5d, 0x03 // cmp eq r13 0x03fc0000
};
const byte kInstruction_cmp_eq_r3_0x00000ff0[] = {
  0xff, 0x0e, 0x53, 0x03 // cmp eq r3 0x00000ff0
};
const byte kInstruction_cmp_hi_r12_0x00002ac0[] = {
  0xab, 0x0d, 0x5c, 0x83 // cmp hi r12 0x00002ac0
};
const byte kInstruction_cmp_mi_r2_0x0ff00000[] = {
  0xff, 0x06, 0x52, 0x43 // cmp mi r2 0x0ff00000
};
const byte kInstruction_cmp_ne_r9_0x003fc000[] = {
  0xff, 0x09, 0x59, 0x13 // cmp ne r9 0x003fc000
};
const byte kInstruction_cmp_eq_r14_0x03fc0000[] = {
  0xff, 0x07, 0x5e, 0x03 // cmp eq r14 0x03fc0000
};
const byte kInstruction_cmp_cc_r0_0x002ac000[] = {
  0xab, 0x09, 0x50, 0x33 // cmp cc r0 0x002ac000
};
const byte kInstruction_cmp_vc_r14_0x00000ab0[] = {
  0xab, 0x0e, 0x5e, 0x73 // cmp vc r14 0x00000ab0
};
const byte kInstruction_cmp_mi_r15_0xf000000f[] = {
  0xff, 0x02, 0x5f, 0x43 // cmp mi r15 0xf000000f
};
const byte kInstruction_cmp_ge_r9_0x000003fc[] = {
  0xff, 0x0f, 0x59, 0xa3 // cmp ge r9 0x000003fc
};
const byte kInstruction_cmp_vs_r13_0xac000002[] = {
  0xab, 0x03, 0x5d, 0x63 // cmp vs r13 0xac000002
};
const byte kInstruction_cmp_vs_r1_0x3fc00000[] = {
  0xff, 0x05, 0x51, 0x63 // cmp vs r1 0x3fc00000
};
const byte kInstruction_cmp_eq_r12_0x00003fc0[] = {
  0xff, 0x0d, 0x5c, 0x03 // cmp eq r12 0x00003fc0
};
const byte kInstruction_cmp_mi_r6_0xff000000[] = {
  0xff, 0x04, 0x56, 0x43 // cmp mi r6 0xff000000
};
const byte kInstruction_cmp_ne_r5_0x000003fc[] = {
  0xff, 0x0f, 0x55, 0x13 // cmp ne r5 0x000003fc
};
const byte kInstruction_cmp_lt_r8_0x0ff00000[] = {
  0xff, 0x06, 0x58, 0xb3 // cmp lt r8 0x0ff00000
};
const byte kInstruction_cmp_hi_r7_0x3fc00000[] = {
  0xff, 0x05, 0x57, 0x83 // cmp hi r7 0x3fc00000
};
const byte kInstruction_cmp_ge_r10_0xac000002[] = {
  0xab, 0x03, 0x5a, 0xa3 // cmp ge r10 0xac000002
};
const byte kInstruction_cmp_vs_r2_0x0000ff00[] = {
  0xff, 0x0c, 0x52, 0x63 // cmp vs r2 0x0000ff00
};
const byte kInstruction_cmp_al_r6_0x000000ab[] = {
  0xab, 0x00, 0x56, 0xe3 // cmp al r6 0x000000ab
};
const byte kInstruction_cmp_ge_r7_0x00ff0000[] = {
  0xff, 0x08, 0x57, 0xa3 // cmp ge r7 0x00ff0000
};
const byte kInstruction_cmp_ne_r0_0x000ff000[] = {
  0xff, 0x0a, 0x50, 0x13 // cmp ne r0 0x000ff000
};
const byte kInstruction_cmp_mi_r6_0x000000ab[] = {
  0xab, 0x00, 0x56, 0x43 // cmp mi r6 0x000000ab
};
const byte kInstruction_cmp_hi_r1_0xf000000f[] = {
  0xff, 0x02, 0x51, 0x83 // cmp hi r1 0xf000000f
};
const byte kInstruction_cmp_mi_r6_0x2ac00000[] = {
  0xab, 0x05, 0x56, 0x43 // cmp mi r6 0x2ac00000
};
const byte kInstruction_cmp_vc_r11_0x000000ff[] = {
  0xff, 0x00, 0x5b, 0x73 // cmp vc r11 0x000000ff
};
const byte kInstruction_cmp_ls_r14_0x02ac0000[] = {
  0xab, 0x07, 0x5e, 0x93 // cmp ls r14 0x02ac0000
};
const byte kInstruction_cmp_ge_r5_0x003fc000[] = {
  0xff, 0x09, 0x55, 0xa3 // cmp ge r5 0x003fc000
};
const byte kInstruction_cmp_ls_r12_0x0000ab00[] = {
  0xab, 0x0c, 0x5c, 0x93 // cmp ls r12 0x0000ab00
};
const byte kInstruction_cmp_cc_r15_0x00000ab0[] = {
  0xab, 0x0e, 0x5f, 0x33 // cmp cc r15 0x00000ab0
};
const byte kInstruction_cmp_vc_r12_0x0000ab00[] = {
  0xab, 0x0c, 0x5c, 0x73 // cmp vc r12 0x0000ab00
};
const byte kInstruction_cmp_vs_r2_0xc000002a[] = {
  0xab, 0x01, 0x52, 0x63 // cmp vs r2 0xc000002a
};
const byte kInstruction_cmp_lt_r7_0x0ab00000[] = {
  0xab, 0x06, 0x57, 0xb3 // cmp lt r7 0x0ab00000
};
const byte kInstruction_cmp_ls_r6_0x00000ff0[] = {
  0xff, 0x0e, 0x56, 0x93 // cmp ls r6 0x00000ff0
};
const byte kInstruction_cmp_vc_r10_0x000000ff[] = {
  0xff, 0x00, 0x5a, 0x73 // cmp vc r10 0x000000ff
};
const byte kInstruction_cmp_ls_r4_0x0000ab00[] = {
  0xab, 0x0c, 0x54, 0x93 // cmp ls r4 0x0000ab00
};
const byte kInstruction_cmp_mi_r10_0x003fc000[] = {
  0xff, 0x09, 0x5a, 0x43 // cmp mi r10 0x003fc000
};
const byte kInstruction_cmp_ls_r1_0x000002ac[] = {
  0xab, 0x0f, 0x51, 0x93 // cmp ls r1 0x000002ac
};
const byte kInstruction_cmp_ge_r7_0xb000000a[] = {
  0xab, 0x02, 0x57, 0xa3 // cmp ge r7 0xb000000a
};
const byte kInstruction_cmp_gt_r4_0xf000000f[] = {
  0xff, 0x02, 0x54, 0xc3 // cmp gt r4 0xf000000f
};
const byte kInstruction_cmp_vc_r8_0x002ac000[] = {
  0xab, 0x09, 0x58, 0x73 // cmp vc r8 0x002ac000
};
const byte kInstruction_cmp_eq_r5_0x0ab00000[] = {
  0xab, 0x06, 0x55, 0x03 // cmp eq r5 0x0ab00000
};
const byte kInstruction_cmp_gt_r2_0xf000000f[] = {
  0xff, 0x02, 0x52, 0xc3 // cmp gt r2 0xf000000f
};
const byte kInstruction_cmp_gt_r6_0xff000000[] = {
  0xff, 0x04, 0x56, 0xc3 // cmp gt r6 0xff000000
};
const byte kInstruction_cmp_ls_r8_0x0ab00000[] = {
  0xab, 0x06, 0x58, 0x93 // cmp ls r8 0x0ab00000
};
const byte kInstruction_cmp_vc_r0_0xb000000a[] = {
  0xab, 0x02, 0x50, 0x73 // cmp vc r0 0xb000000a
};
const byte kInstruction_cmp_lt_r6_0x03fc0000[] = {
  0xff, 0x07, 0x56, 0xb3 // cmp lt r6 0x03fc0000
};
const byte kInstruction_cmp_ge_r10_0x0000ab00[] = {
  0xab, 0x0c, 0x5a, 0xa3 // cmp ge r10 0x0000ab00
};
const byte kInstruction_cmp_hi_r4_0x000ab000[] = {
  0xab, 0x0a, 0x54, 0x83 // cmp hi r4 0x000ab000
};
const byte kInstruction_cmp_hi_r11_0x3fc00000[] = {
  0xff, 0x05, 0x5b, 0x83 // cmp hi r11 0x3fc00000
};
const byte kInstruction_cmp_vs_r12_0xc000003f[] = {
  0xff, 0x01, 0x5c, 0x63 // cmp vs r12 0xc000003f
};
const byte kInstruction_cmp_gt_r12_0xb000000a[] = {
  0xab, 0x02, 0x5c, 0xc3 // cmp gt r12 0xb000000a
};
const byte kInstruction_cmp_eq_r11_0x2ac00000[] = {
  0xab, 0x05, 0x5b, 0x03 // cmp eq r11 0x2ac00000
};
const byte kInstruction_cmp_hi_r0_0xc000003f[] = {
  0xff, 0x01, 0x50, 0x83 // cmp hi r0 0xc000003f
};
const byte kInstruction_cmp_cs_r12_0xac000002[] = {
  0xab, 0x03, 0x5c, 0x23 // cmp cs r12 0xac000002
};
const byte kInstruction_cmp_hi_r9_0x3fc00000[] = {
  0xff, 0x05, 0x59, 0x83 // cmp hi r9 0x3fc00000
};
const byte kInstruction_cmp_vs_r2_0x00002ac0[] = {
  0xab, 0x0d, 0x52, 0x63 // cmp vs r2 0x00002ac0
};
const byte kInstruction_cmp_al_r12_0xb000000a[] = {
  0xab, 0x02, 0x5c, 0xe3 // cmp al r12 0xb000000a
};
const byte kInstruction_cmp_gt_r12_0x3fc00000[] = {
  0xff, 0x05, 0x5c, 0xc3 // cmp gt r12 0x3fc00000
};
const byte kInstruction_cmp_gt_r6_0xf000000f[] = {
  0xff, 0x02, 0x56, 0xc3 // cmp gt r6 0xf000000f
};
const byte kInstruction_cmp_vc_r14_0x000000ff[] = {
  0xff, 0x00, 0x5e, 0x73 // cmp vc r14 0x000000ff
};
const byte kInstruction_cmp_pl_r7_0x0002ac00[] = {
  0xab, 0x0b, 0x57, 0x53 // cmp pl r7 0x0002ac00
};
const byte kInstruction_cmp_ge_r1_0x03fc0000[] = {
  0xff, 0x07, 0x51, 0xa3 // cmp ge r1 0x03fc0000
};
const byte kInstruction_cmp_hi_r10_0x0002ac00[] = {
  0xab, 0x0b, 0x5a, 0x83 // cmp hi r10 0x0002ac00
};
const byte kInstruction_cmp_gt_r4_0x002ac000[] = {
  0xab, 0x09, 0x54, 0xc3 // cmp gt r4 0x002ac000
};
const byte kInstruction_cmp_vc_r5_0x000000ff[] = {
  0xff, 0x00, 0x55, 0x73 // cmp vc r5 0x000000ff
};
const byte kInstruction_cmp_pl_r15_0x0000ab00[] = {
  0xab, 0x0c, 0x5f, 0x53 // cmp pl r15 0x0000ab00
};
const byte kInstruction_cmp_cc_r4_0x00ab0000[] = {
  0xab, 0x08, 0x54, 0x33 // cmp cc r4 0x00ab0000
};
const byte kInstruction_cmp_pl_r11_0xff000000[] = {
  0xff, 0x04, 0x5b, 0x53 // cmp pl r11 0xff000000
};
const byte kInstruction_cmp_pl_r2_0xf000000f[] = {
  0xff, 0x02, 0x52, 0x53 // cmp pl r2 0xf000000f
};
const byte kInstruction_cmp_cc_r8_0xb000000a[] = {
  0xab, 0x02, 0x58, 0x33 // cmp cc r8 0xb000000a
};
const byte kInstruction_cmp_al_r13_0x000000ff[] = {
  0xff, 0x00, 0x5d, 0xe3 // cmp al r13 0x000000ff
};
const byte kInstruction_cmp_mi_r6_0x000003fc[] = {
  0xff, 0x0f, 0x56, 0x43 // cmp mi r6 0x000003fc
};
const byte kInstruction_cmp_vs_r13_0x02ac0000[] = {
  0xab, 0x07, 0x5d, 0x63 // cmp vs r13 0x02ac0000
};
const byte kInstruction_cmp_mi_r4_0x00ff0000[] = {
  0xff, 0x08, 0x54, 0x43 // cmp mi r4 0x00ff0000
};
const byte kInstruction_cmp_cs_r3_0x000003fc[] = {
  0xff, 0x0f, 0x53, 0x23 // cmp cs r3 0x000003fc
};
const byte kInstruction_cmp_pl_r13_0xab000000[] = {
  0xab, 0x04, 0x5d, 0x53 // cmp pl r13 0xab000000
};
const byte kInstruction_cmp_ls_r9_0x002ac000[] = {
  0xab, 0x09, 0x59, 0x93 // cmp ls r9 0x002ac000
};
const byte kInstruction_cmp_eq_r1_0xc000002a[] = {
  0xab, 0x01, 0x51, 0x03 // cmp eq r1 0xc000002a
};
const byte kInstruction_cmp_lt_r12_0x00000000[] = {
  0x00, 0x00, 0x5c, 0xb3 // cmp lt r12 0x00000000
};
const byte kInstruction_cmp_ge_r14_0xff000000[] = {
  0xff, 0x04, 0x5e, 0xa3 // cmp ge r14 0xff000000
};
const byte kInstruction_cmp_lt_r9_0x002ac000[] = {
  0xab, 0x09, 0x59, 0xb3 // cmp lt r9 0x002ac000
};
const byte kInstruction_cmp_lt_r10_0x00000ff0[] = {
  0xff, 0x0e, 0x5a, 0xb3 // cmp lt r10 0x00000ff0
};
const byte kInstruction_cmp_vs_r5_0x000000ff[] = {
  0xff, 0x00, 0x55, 0x63 // cmp vs r5 0x000000ff
};
const byte kInstruction_cmp_cc_r12_0x03fc0000[] = {
  0xff, 0x07, 0x5c, 0x33 // cmp cc r12 0x03fc0000
};
const byte kInstruction_cmp_ne_r4_0x00000000[] = {
  0x00, 0x00, 0x54, 0x13 // cmp ne r4 0x00000000
};
const byte kInstruction_cmp_mi_r13_0xff000000[] = {
  0xff, 0x04, 0x5d, 0x43 // cmp mi r13 0xff000000
};
const byte kInstruction_cmp_ne_r7_0x00000ff0[] = {
  0xff, 0x0e, 0x57, 0x13 // cmp ne r7 0x00000ff0
};
const byte kInstruction_cmp_vs_r2_0xc000003f[] = {
  0xff, 0x01, 0x52, 0x63 // cmp vs r2 0xc000003f
};
const byte kInstruction_cmp_al_r5_0x00ff0000[] = {
  0xff, 0x08, 0x55, 0xe3 // cmp al r5 0x00ff0000
};
const byte kInstruction_cmp_hi_r15_0x00000ff0[] = {
  0xff, 0x0e, 0x5f, 0x83 // cmp hi r15 0x00000ff0
};
const byte kInstruction_cmp_ls_r8_0x00003fc0[] = {
  0xff, 0x0d, 0x58, 0x93 // cmp ls r8 0x00003fc0
};
const byte kInstruction_cmp_vs_r0_0xff000000[] = {
  0xff, 0x04, 0x50, 0x63 // cmp vs r0 0xff000000
};
const byte kInstruction_cmp_vs_r6_0x000000ab[] = {
  0xab, 0x00, 0x56, 0x63 // cmp vs r6 0x000000ab
};
const byte kInstruction_cmp_cs_r9_0x00ab0000[] = {
  0xab, 0x08, 0x59, 0x23 // cmp cs r9 0x00ab0000
};
const byte kInstruction_cmp_hi_r1_0x0002ac00[] = {
  0xab, 0x0b, 0x51, 0x83 // cmp hi r1 0x0002ac00
};
const byte kInstruction_cmp_hi_r15_0x2ac00000[] = {
  0xab, 0x05, 0x5f, 0x83 // cmp hi r15 0x2ac00000
};
const byte kInstruction_cmp_hi_r6_0x0002ac00[] = {
  0xab, 0x0b, 0x56, 0x83 // cmp hi r6 0x0002ac00
};
const byte kInstruction_cmp_ge_r4_0xc000003f[] = {
  0xff, 0x01, 0x54, 0xa3 // cmp ge r4 0xc000003f
};
const byte kInstruction_cmp_ls_r10_0x0000ff00[] = {
  0xff, 0x0c, 0x5a, 0x93 // cmp ls r10 0x0000ff00
};
const byte kInstruction_cmp_ne_r11_0x000003fc[] = {
  0xff, 0x0f, 0x5b, 0x13 // cmp ne r11 0x000003fc
};
const byte kInstruction_cmp_ls_r3_0x0002ac00[] = {
  0xab, 0x0b, 0x53, 0x93 // cmp ls r3 0x0002ac00
};
const byte kInstruction_cmp_al_r12_0x000003fc[] = {
  0xff, 0x0f, 0x5c, 0xe3 // cmp al r12 0x000003fc
};
const byte kInstruction_cmp_le_r7_0xf000000f[] = {
  0xff, 0x02, 0x57, 0xd3 // cmp le r7 0xf000000f
};
const byte kInstruction_cmp_al_r11_0x00000ab0[] = {
  0xab, 0x0e, 0x5b, 0xe3 // cmp al r11 0x00000ab0
};
const byte kInstruction_cmp_cs_r13_0x02ac0000[] = {
  0xab, 0x07, 0x5d, 0x23 // cmp cs r13 0x02ac0000
};
const byte kInstruction_cmp_hi_r1_0x00000ff0[] = {
  0xff, 0x0e, 0x51, 0x83 // cmp hi r1 0x00000ff0
};
const byte kInstruction_cmp_le_r11_0x3fc00000[] = {
  0xff, 0x05, 0x5b, 0xd3 // cmp le r11 0x3fc00000
};
const byte kInstruction_cmp_hi_r9_0x000003fc[] = {
  0xff, 0x0f, 0x59, 0x83 // cmp hi r9 0x000003fc
};
const byte kInstruction_cmp_mi_r13_0x000002ac[] = {
  0xab, 0x0f, 0x5d, 0x43 // cmp mi r13 0x000002ac
};
const byte kInstruction_cmp_lt_r12_0x000003fc[] = {
  0xff, 0x0f, 0x5c, 0xb3 // cmp lt r12 0x000003fc
};
const byte kInstruction_cmp_lt_r14_0x00000ab0[] = {
  0xab, 0x0e, 0x5e, 0xb3 // cmp lt r14 0x00000ab0
};
const byte kInstruction_cmp_gt_r1_0x3fc00000[] = {
  0xff, 0x05, 0x51, 0xc3 // cmp gt r1 0x3fc00000
};
const byte kInstruction_cmp_cc_r14_0xb000000a[] = {
  0xab, 0x02, 0x5e, 0x33 // cmp cc r14 0xb000000a
};
const byte kInstruction_cmp_ge_r0_0x000002ac[] = {
  0xab, 0x0f, 0x50, 0xa3 // cmp ge r0 0x000002ac
};
const byte kInstruction_cmp_eq_r12_0x000003fc[] = {
  0xff, 0x0f, 0x5c, 0x03 // cmp eq r12 0x000003fc
};
const byte kInstruction_cmp_vc_r13_0x0ab00000[] = {
  0xab, 0x06, 0x5d, 0x73 // cmp vc r13 0x0ab00000
};
const byte kInstruction_cmp_pl_r10_0x0003fc00[] = {
  0xff, 0x0b, 0x5a, 0x53 // cmp pl r10 0x0003fc00
};
const byte kInstruction_cmp_le_r7_0x0000ff00[] = {
  0xff, 0x0c, 0x57, 0xd3 // cmp le r7 0x0000ff00
};
const byte kInstruction_cmp_eq_r5_0x0003fc00[] = {
  0xff, 0x0b, 0x55, 0x03 // cmp eq r5 0x0003fc00
};
const byte kInstruction_cmp_pl_r1_0xfc000003[] = {
  0xff, 0x03, 0x51, 0x53 // cmp pl r1 0xfc000003
};
const byte kInstruction_cmp_gt_r15_0x000ff000[] = {
  0xff, 0x0a, 0x5f, 0xc3 // cmp gt r15 0x000ff000
};
const byte kInstruction_cmp_mi_r2_0xb000000a[] = {
  0xab, 0x02, 0x52, 0x43 // cmp mi r2 0xb000000a
};
const byte kInstruction_cmp_cs_r8_0x0000ff00[] = {
  0xff, 0x0c, 0x58, 0x23 // cmp cs r8 0x0000ff00
};
const byte kInstruction_cmp_vs_r8_0x00002ac0[] = {
  0xab, 0x0d, 0x58, 0x63 // cmp vs r8 0x00002ac0
};
const byte kInstruction_cmp_cs_r5_0x00ab0000[] = {
  0xab, 0x08, 0x55, 0x23 // cmp cs r5 0x00ab0000
};
const byte kInstruction_cmp_pl_r3_0x00ab0000[] = {
  0xab, 0x08, 0x53, 0x53 // cmp pl r3 0x00ab0000
};
const byte kInstruction_cmp_hi_r5_0x02ac0000[] = {
  0xab, 0x07, 0x55, 0x83 // cmp hi r5 0x02ac0000
};
const byte kInstruction_cmp_cc_r9_0x000002ac[] = {
  0xab, 0x0f, 0x59, 0x33 // cmp cc r9 0x000002ac
};
const byte kInstruction_cmp_ls_r13_0x0000ab00[] = {
  0xab, 0x0c, 0x5d, 0x93 // cmp ls r13 0x0000ab00
};
const byte kInstruction_cmp_pl_r11_0x00000ab0[] = {
  0xab, 0x0e, 0x5b, 0x53 // cmp pl r11 0x00000ab0
};
const byte kInstruction_cmp_ge_r14_0x3fc00000[] = {
  0xff, 0x05, 0x5e, 0xa3 // cmp ge r14 0x3fc00000
};
const byte kInstruction_cmp_al_r14_0x0000ab00[] = {
  0xab, 0x0c, 0x5e, 0xe3 // cmp al r14 0x0000ab00
};
const byte kInstruction_cmp_lt_r6_0xac000002[] = {
  0xab, 0x03, 0x56, 0xb3 // cmp lt r6 0xac000002
};
const byte kInstruction_cmp_vc_r3_0x000ff000[] = {
  0xff, 0x0a, 0x53, 0x73 // cmp vc r3 0x000ff000
};
const byte kInstruction_cmp_ne_r8_0xfc000003[] = {
  0xff, 0x03, 0x58, 0x13 // cmp ne r8 0xfc000003
};
const byte kInstruction_cmp_cs_r6_0x000ab000[] = {
  0xab, 0x0a, 0x56, 0x23 // cmp cs r6 0x000ab000
};
const byte kInstruction_cmp_hi_r15_0x0002ac00[] = {
  0xab, 0x0b, 0x5f, 0x83 // cmp hi r15 0x0002ac00
};
const byte kInstruction_cmp_pl_r6_0x00000ff0[] = {
  0xff, 0x0e, 0x56, 0x53 // cmp pl r6 0x00000ff0
};
const byte kInstruction_cmp_hi_r15_0x03fc0000[] = {
  0xff, 0x07, 0x5f, 0x83 // cmp hi r15 0x03fc0000
};
const byte kInstruction_cmp_cc_r6_0x0003fc00[] = {
  0xff, 0x0b, 0x56, 0x33 // cmp cc r6 0x0003fc00
};
const byte kInstruction_cmp_eq_r12_0x000002ac[] = {
  0xab, 0x0f, 0x5c, 0x03 // cmp eq r12 0x000002ac
};
const byte kInstruction_cmp_ls_r11_0x02ac0000[] = {
  0xab, 0x07, 0x5b, 0x93 // cmp ls r11 0x02ac0000
};
const byte kInstruction_cmp_ge_r13_0x00ff0000[] = {
  0xff, 0x08, 0x5d, 0xa3 // cmp ge r13 0x00ff0000
};
const byte kInstruction_cmp_lt_r4_0x0003fc00[] = {
  0xff, 0x0b, 0x54, 0xb3 // cmp lt r4 0x0003fc00
};
const byte kInstruction_cmp_mi_r0_0x0000ab00[] = {
  0xab, 0x0c, 0x50, 0x43 // cmp mi r0 0x0000ab00
};
const byte kInstruction_cmp_lt_r4_0x000000ab[] = {
  0xab, 0x00, 0x54, 0xb3 // cmp lt r4 0x000000ab
};
const byte kInstruction_cmp_ls_r2_0xc000003f[] = {
  0xff, 0x01, 0x52, 0x93 // cmp ls r2 0xc000003f
};
const byte kInstruction_cmp_pl_r1_0x000000ab[] = {
  0xab, 0x00, 0x51, 0x53 // cmp pl r1 0x000000ab
};
const byte kInstruction_cmp_ne_r10_0x0000ff00[] = {
  0xff, 0x0c, 0x5a, 0x13 // cmp ne r10 0x0000ff00
};
const byte kInstruction_cmp_vc_r15_0x00000ab0[] = {
  0xab, 0x0e, 0x5f, 0x73 // cmp vc r15 0x00000ab0
};
const byte kInstruction_cmp_eq_r6_0x02ac0000[] = {
  0xab, 0x07, 0x56, 0x03 // cmp eq r6 0x02ac0000
};
const byte kInstruction_cmp_cc_r11_0x00000000[] = {
  0x00, 0x00, 0x5b, 0x33 // cmp cc r11 0x00000000
};
const byte kInstruction_cmp_mi_r7_0x002ac000[] = {
  0xab, 0x09, 0x57, 0x43 // cmp mi r7 0x002ac000
};
const byte kInstruction_cmp_hi_r14_0xab000000[] = {
  0xab, 0x04, 0x5e, 0x83 // cmp hi r14 0xab000000
};
const byte kInstruction_cmp_vc_r6_0x0000ff00[] = {
  0xff, 0x0c, 0x56, 0x73 // cmp vc r6 0x0000ff00
};
const byte kInstruction_cmp_al_r5_0x000002ac[] = {
  0xab, 0x0f, 0x55, 0xe3 // cmp al r5 0x000002ac
};
const byte kInstruction_cmp_cc_r12_0x0002ac00[] = {
  0xab, 0x0b, 0x5c, 0x33 // cmp cc r12 0x0002ac00
};
const byte kInstruction_cmp_cc_r10_0x000000ab[] = {
  0xab, 0x00, 0x5a, 0x33 // cmp cc r10 0x000000ab
};
const byte kInstruction_cmp_gt_r5_0x000002ac[] = {
  0xab, 0x0f, 0x55, 0xc3 // cmp gt r5 0x000002ac
};
const byte kInstruction_cmp_vc_r3_0x00000000[] = {
  0x00, 0x00, 0x53, 0x73 // cmp vc r3 0x00000000
};
const byte kInstruction_cmp_gt_r12_0xac000002[] = {
  0xab, 0x03, 0x5c, 0xc3 // cmp gt r12 0xac000002
};
const byte kInstruction_cmp_al_r10_0x00ab0000[] = {
  0xab, 0x08, 0x5a, 0xe3 // cmp al r10 0x00ab0000
};
const byte kInstruction_cmp_mi_r5_0x000ff000[] = {
  0xff, 0x0a, 0x55, 0x43 // cmp mi r5 0x000ff000
};
const byte kInstruction_cmp_pl_r1_0x00000ff0[] = {
  0xff, 0x0e, 0x51, 0x53 // cmp pl r1 0x00000ff0
};
const byte kInstruction_cmp_lt_r7_0xf000000f[] = {
  0xff, 0x02, 0x57, 0xb3 // cmp lt r7 0xf000000f
};
const byte kInstruction_cmp_ge_r14_0x002ac000[] = {
  0xab, 0x09, 0x5e, 0xa3 // cmp ge r14 0x002ac000
};
const byte kInstruction_cmp_cc_r0_0xac000002[] = {
  0xab, 0x03, 0x50, 0x33 // cmp cc r0 0xac000002
};
const byte kInstruction_cmp_cs_r2_0x00000ab0[] = {
  0xab, 0x0e, 0x52, 0x23 // cmp cs r2 0x00000ab0
};
const byte kInstruction_cmp_vs_r0_0x00002ac0[] = {
  0xab, 0x0d, 0x50, 0x63 // cmp vs r0 0x00002ac0
};
const byte kInstruction_cmp_le_r10_0x000ab000[] = {
  0xab, 0x0a, 0x5a, 0xd3 // cmp le r10 0x000ab000
};
const byte kInstruction_cmp_ge_r9_0x0003fc00[] = {
  0xff, 0x0b, 0x59, 0xa3 // cmp ge r9 0x0003fc00
};
const byte kInstruction_cmp_lt_r1_0x00003fc0[] = {
  0xff, 0x0d, 0x51, 0xb3 // cmp lt r1 0x00003fc0
};
const byte kInstruction_cmp_ge_r5_0x000000ff[] = {
  0xff, 0x00, 0x55, 0xa3 // cmp ge r5 0x000000ff
};
const byte kInstruction_cmp_le_r11_0x2ac00000[] = {
  0xab, 0x05, 0x5b, 0xd3 // cmp le r11 0x2ac00000
};
const byte kInstruction_cmp_le_r9_0x002ac000[] = {
  0xab, 0x09, 0x59, 0xd3 // cmp le r9 0x002ac000
};
const byte kInstruction_cmp_hi_r12_0xf000000f[] = {
  0xff, 0x02, 0x5c, 0x83 // cmp hi r12 0xf000000f
};
const byte kInstruction_cmp_lt_r3_0x02ac0000[] = {
  0xab, 0x07, 0x53, 0xb3 // cmp lt r3 0x02ac0000
};
const byte kInstruction_cmp_al_r13_0x2ac00000[] = {
  0xab, 0x05, 0x5d, 0xe3 // cmp al r13 0x2ac00000
};
const byte kInstruction_cmp_vs_r12_0x00000ab0[] = {
  0xab, 0x0e, 0x5c, 0x63 // cmp vs r12 0x00000ab0
};
const byte kInstruction_cmp_gt_r3_0x3fc00000[] = {
  0xff, 0x05, 0x53, 0xc3 // cmp gt r3 0x3fc00000
};
const byte kInstruction_cmp_gt_r0_0x2ac00000[] = {
  0xab, 0x05, 0x50, 0xc3 // cmp gt r0 0x2ac00000
};
const byte kInstruction_cmp_eq_r15_0x000002ac[] = {
  0xab, 0x0f, 0x5f, 0x03 // cmp eq r15 0x000002ac
};
const byte kInstruction_cmp_gt_r1_0x000ab000[] = {
  0xab, 0x0a, 0x51, 0xc3 // cmp gt r1 0x000ab000
};
const byte kInstruction_cmp_gt_r2_0x2ac00000[] = {
  0xab, 0x05, 0x52, 0xc3 // cmp gt r2 0x2ac00000
};
const byte kInstruction_cmp_mi_r15_0x00ab0000[] = {
  0xab, 0x08, 0x5f, 0x43 // cmp mi r15 0x00ab0000
};
const byte kInstruction_cmp_mi_r1_0x000ab000[] = {
  0xab, 0x0a, 0x51, 0x43 // cmp mi r1 0x000ab000
};
const byte kInstruction_cmp_ge_r12_0x0ab00000[] = {
  0xab, 0x06, 0x5c, 0xa3 // cmp ge r12 0x0ab00000
};
const byte kInstruction_cmp_gt_r5_0x000000ab[] = {
  0xab, 0x00, 0x55, 0xc3 // cmp gt r5 0x000000ab
};
const byte kInstruction_cmp_gt_r4_0x00000000[] = {
  0x00, 0x00, 0x54, 0xc3 // cmp gt r4 0x00000000
};
const byte kInstruction_cmp_al_r13_0xc000003f[] = {
  0xff, 0x01, 0x5d, 0xe3 // cmp al r13 0xc000003f
};
const byte kInstruction_cmp_ls_r7_0xff000000[] = {
  0xff, 0x04, 0x57, 0x93 // cmp ls r7 0xff000000
};
const byte kInstruction_cmp_vs_r0_0x00000ff0[] = {
  0xff, 0x0e, 0x50, 0x63 // cmp vs r0 0x00000ff0
};
const byte kInstruction_cmp_hi_r9_0x02ac0000[] = {
  0xab, 0x07, 0x59, 0x83 // cmp hi r9 0x02ac0000
};
const byte kInstruction_cmp_cs_r1_0xc000002a[] = {
  0xab, 0x01, 0x51, 0x23 // cmp cs r1 0xc000002a
};
const byte kInstruction_cmp_hi_r8_0xf000000f[] = {
  0xff, 0x02, 0x58, 0x83 // cmp hi r8 0xf000000f
};
const byte kInstruction_cmp_gt_r1_0xb000000a[] = {
  0xab, 0x02, 0x51, 0xc3 // cmp gt r1 0xb000000a
};
const byte kInstruction_cmp_gt_r2_0x0002ac00[] = {
  0xab, 0x0b, 0x52, 0xc3 // cmp gt r2 0x0002ac00
};
const byte kInstruction_cmp_vs_r5_0x000000ab[] = {
  0xab, 0x00, 0x55, 0x63 // cmp vs r5 0x000000ab
};
const byte kInstruction_cmp_cc_r12_0x000ff000[] = {
  0xff, 0x0a, 0x5c, 0x33 // cmp cc r12 0x000ff000
};
const byte kInstruction_cmp_ge_r0_0x00003fc0[] = {
  0xff, 0x0d, 0x50, 0xa3 // cmp ge r0 0x00003fc0
};
const byte kInstruction_cmp_ls_r12_0x00ab0000[] = {
  0xab, 0x08, 0x5c, 0x93 // cmp ls r12 0x00ab0000
};
const byte kInstruction_cmp_vs_r4_0x000003fc[] = {
  0xff, 0x0f, 0x54, 0x63 // cmp vs r4 0x000003fc
};
const byte kInstruction_cmp_ls_r4_0x00003fc0[] = {
  0xff, 0x0d, 0x54, 0x93 // cmp ls r4 0x00003fc0
};
const byte kInstruction_cmp_eq_r9_0xb000000a[] = {
  0xab, 0x02, 0x59, 0x03 // cmp eq r9 0xb000000a
};
const byte kInstruction_cmp_cs_r9_0x2ac00000[] = {
  0xab, 0x05, 0x59, 0x23 // cmp cs r9 0x2ac00000
};
const byte kInstruction_cmp_vs_r12_0x0000ff00[] = {
  0xff, 0x0c, 0x5c, 0x63 // cmp vs r12 0x0000ff00
};
const byte kInstruction_cmp_vc_r1_0x0000ff00[] = {
  0xff, 0x0c, 0x51, 0x73 // cmp vc r1 0x0000ff00
};
const byte kInstruction_cmp_hi_r12_0xff000000[] = {
  0xff, 0x04, 0x5c, 0x83 // cmp hi r12 0xff000000
};
const byte kInstruction_cmp_cs_r12_0x0002ac00[] = {
  0xab, 0x0b, 0x5c, 0x23 // cmp cs r12 0x0002ac00
};
const byte kInstruction_cmp_mi_r11_0x03fc0000[] = {
  0xff, 0x07, 0x5b, 0x43 // cmp mi r11 0x03fc0000
};
const byte kInstruction_cmp_eq_r2_0x000ff000[] = {
  0xff, 0x0a, 0x52, 0x03 // cmp eq r2 0x000ff000
};
const byte kInstruction_cmp_al_r6_0x00000ff0[] = {
  0xff, 0x0e, 0x56, 0xe3 // cmp al r6 0x00000ff0
};
const byte kInstruction_cmp_cs_r7_0x000003fc[] = {
  0xff, 0x0f, 0x57, 0x23 // cmp cs r7 0x000003fc
};
const byte kInstruction_cmp_pl_r11_0xb000000a[] = {
  0xab, 0x02, 0x5b, 0x53 // cmp pl r11 0xb000000a
};
const byte kInstruction_cmp_ne_r15_0x000ff000[] = {
  0xff, 0x0a, 0x5f, 0x13 // cmp ne r15 0x000ff000
};
const byte kInstruction_cmp_mi_r14_0x00ab0000[] = {
  0xab, 0x08, 0x5e, 0x43 // cmp mi r14 0x00ab0000
};
const byte kInstruction_cmp_hi_r4_0x0000ff00[] = {
  0xff, 0x0c, 0x54, 0x83 // cmp hi r4 0x0000ff00
};
const byte kInstruction_cmp_ge_r1_0x000002ac[] = {
  0xab, 0x0f, 0x51, 0xa3 // cmp ge r1 0x000002ac
};
const byte kInstruction_cmp_gt_r7_0xb000000a[] = {
  0xab, 0x02, 0x57, 0xc3 // cmp gt r7 0xb000000a
};
const byte kInstruction_cmp_gt_r2_0x00000000[] = {
  0x00, 0x00, 0x52, 0xc3 // cmp gt r2 0x00000000
};
const byte kInstruction_cmp_cc_r2_0xb000000a[] = {
  0xab, 0x02, 0x52, 0x33 // cmp cc r2 0xb000000a
};
const byte kInstruction_cmp_vs_r14_0x000ab000[] = {
  0xab, 0x0a, 0x5e, 0x63 // cmp vs r14 0x000ab000
};
const byte kInstruction_cmp_lt_r5_0x000002ac[] = {
  0xab, 0x0f, 0x55, 0xb3 // cmp lt r5 0x000002ac
};
const byte kInstruction_cmp_cc_r13_0x0000ff00[] = {
  0xff, 0x0c, 0x5d, 0x33 // cmp cc r13 0x0000ff00
};
const byte kInstruction_cmp_hi_r15_0x000002ac[] = {
  0xab, 0x0f, 0x5f, 0x83 // cmp hi r15 0x000002ac
};
const byte kInstruction_cmp_ge_r1_0x00ff0000[] = {
  0xff, 0x08, 0x51, 0xa3 // cmp ge r1 0x00ff0000
};
const byte kInstruction_cmp_lt_r15_0x00002ac0[] = {
  0xab, 0x0d, 0x5f, 0xb3 // cmp lt r15 0x00002ac0
};
const byte kInstruction_cmp_lt_r8_0x000ff000[] = {
  0xff, 0x0a, 0x58, 0xb3 // cmp lt r8 0x000ff000
};
const byte kInstruction_cmp_hi_r10_0xc000002a[] = {
  0xab, 0x01, 0x5a, 0x83 // cmp hi r10 0xc000002a
};
const byte kInstruction_cmp_eq_r12_0x000ab000[] = {
  0xab, 0x0a, 0x5c, 0x03 // cmp eq r12 0x000ab000
};
const byte kInstruction_cmp_vs_r11_0x00002ac0[] = {
  0xab, 0x0d, 0x5b, 0x63 // cmp vs r11 0x00002ac0
};
const byte kInstruction_cmp_hi_r10_0x000003fc[] = {
  0xff, 0x0f, 0x5a, 0x83 // cmp hi r10 0x000003fc
};
const byte kInstruction_cmp_cc_r8_0x000003fc[] = {
  0xff, 0x0f, 0x58, 0x33 // cmp cc r8 0x000003fc
};
const byte kInstruction_cmp_vc_r11_0x00000ab0[] = {
  0xab, 0x0e, 0x5b, 0x73 // cmp vc r11 0x00000ab0
};
const byte kInstruction_cmp_le_r3_0xac000002[] = {
  0xab, 0x03, 0x53, 0xd3 // cmp le r3 0xac000002
};
const byte kInstruction_cmp_cc_r11_0xc000002a[] = {
  0xab, 0x01, 0x5b, 0x33 // cmp cc r11 0xc000002a
};
const byte kInstruction_cmp_lt_r6_0xab000000[] = {
  0xab, 0x04, 0x56, 0xb3 // cmp lt r6 0xab000000
};
const byte kInstruction_cmp_hi_r1_0x00003fc0[] = {
  0xff, 0x0d, 0x51, 0x83 // cmp hi r1 0x00003fc0
};
const byte kInstruction_cmp_vc_r3_0x00002ac0[] = {
  0xab, 0x0d, 0x53, 0x73 // cmp vc r3 0x00002ac0
};
const byte kInstruction_cmp_vc_r6_0x00000ab0[] = {
  0xab, 0x0e, 0x56, 0x73 // cmp vc r6 0x00000ab0
};
const byte kInstruction_cmp_ls_r6_0x03fc0000[] = {
  0xff, 0x07, 0x56, 0x93 // cmp ls r6 0x03fc0000
};
const byte kInstruction_cmp_hi_r11_0x0ab00000[] = {
  0xab, 0x06, 0x5b, 0x83 // cmp hi r11 0x0ab00000
};
const byte kInstruction_cmp_lt_r12_0x0002ac00[] = {
  0xab, 0x0b, 0x5c, 0xb3 // cmp lt r12 0x0002ac00
};
const byte kInstruction_cmp_al_r8_0xab000000[] = {
  0xab, 0x04, 0x58, 0xe3 // cmp al r8 0xab000000
};
const byte kInstruction_cmp_vs_r2_0x00000ab0[] = {
  0xab, 0x0e, 0x52, 0x63 // cmp vs r2 0x00000ab0
};
const byte kInstruction_cmp_hi_r14_0x02ac0000[] = {
  0xab, 0x07, 0x5e, 0x83 // cmp hi r14 0x02ac0000
};
const byte kInstruction_cmp_cs_r3_0x00000ff0[] = {
  0xff, 0x0e, 0x53, 0x23 // cmp cs r3 0x00000ff0
};
const byte kInstruction_cmp_cc_r9_0xb000000a[] = {
  0xab, 0x02, 0x59, 0x33 // cmp cc r9 0xb000000a
};
const byte kInstruction_cmp_vc_r9_0x00000ff0[] = {
  0xff, 0x0e, 0x59, 0x73 // cmp vc r9 0x00000ff0
};
const byte kInstruction_cmp_ne_r9_0xab000000[] = {
  0xab, 0x04, 0x59, 0x13 // cmp ne r9 0xab000000
};
const byte kInstruction_cmp_cc_r10_0xb000000a[] = {
  0xab, 0x02, 0x5a, 0x33 // cmp cc r10 0xb000000a
};
const byte kInstruction_cmp_ls_r11_0xb000000a[] = {
  0xab, 0x02, 0x5b, 0x93 // cmp ls r11 0xb000000a
};
const byte kInstruction_cmp_lt_r11_0x00ff0000[] = {
  0xff, 0x08, 0x5b, 0xb3 // cmp lt r11 0x00ff0000
};
const byte kInstruction_cmp_lt_r3_0x000003fc[] = {
  0xff, 0x0f, 0x53, 0xb3 // cmp lt r3 0x000003fc
};
const byte kInstruction_cmp_gt_r14_0x00002ac0[] = {
  0xab, 0x0d, 0x5e, 0xc3 // cmp gt r14 0x00002ac0
};
const byte kInstruction_cmp_ls_r8_0xc000003f[] = {
  0xff, 0x01, 0x58, 0x93 // cmp ls r8 0xc000003f
};
const byte kInstruction_cmp_al_r11_0x000ab000[] = {
  0xab, 0x0a, 0x5b, 0xe3 // cmp al r11 0x000ab000
};
const byte kInstruction_cmp_lt_r7_0x000ab000[] = {
  0xab, 0x0a, 0x57, 0xb3 // cmp lt r7 0x000ab000
};
const byte kInstruction_cmp_vs_r14_0xff000000[] = {
  0xff, 0x04, 0x5e, 0x63 // cmp vs r14 0xff000000
};
const byte kInstruction_cmp_vc_r2_0xab000000[] = {
  0xab, 0x04, 0x52, 0x73 // cmp vc r2 0xab000000
};
const byte kInstruction_cmp_ne_r3_0x00000ff0[] = {
  0xff, 0x0e, 0x53, 0x13 // cmp ne r3 0x00000ff0
};
const byte kInstruction_cmp_ne_r15_0x02ac0000[] = {
  0xab, 0x07, 0x5f, 0x13 // cmp ne r15 0x02ac0000
};
const byte kInstruction_cmp_gt_r3_0x000ff000[] = {
  0xff, 0x0a, 0x53, 0xc3 // cmp gt r3 0x000ff000
};
const byte kInstruction_cmp_pl_r1_0x2ac00000[] = {
  0xab, 0x05, 0x51, 0x53 // cmp pl r1 0x2ac00000
};
const byte kInstruction_cmp_mi_r1_0x00002ac0[] = {
  0xab, 0x0d, 0x51, 0x43 // cmp mi r1 0x00002ac0
};
const byte kInstruction_cmp_vc_r6_0xac000002[] = {
  0xab, 0x03, 0x56, 0x73 // cmp vc r6 0xac000002
};
const byte kInstruction_cmp_vs_r2_0x0ff00000[] = {
  0xff, 0x06, 0x52, 0x63 // cmp vs r2 0x0ff00000
};
const byte kInstruction_cmp_ge_r2_0x000003fc[] = {
  0xff, 0x0f, 0x52, 0xa3 // cmp ge r2 0x000003fc
};
const byte kInstruction_cmp_cs_r15_0x0000ff00[] = {
  0xff, 0x0c, 0x5f, 0x23 // cmp cs r15 0x0000ff00
};
const byte kInstruction_cmp_lt_r3_0x000002ac[] = {
  0xab, 0x0f, 0x53, 0xb3 // cmp lt r3 0x000002ac
};
const byte kInstruction_cmp_cs_r6_0xff000000[] = {
  0xff, 0x04, 0x56, 0x23 // cmp cs r6 0xff000000
};
const byte kInstruction_cmp_ge_r14_0x000000ff[] = {
  0xff, 0x00, 0x5e, 0xa3 // cmp ge r14 0x000000ff
};
const byte kInstruction_cmp_gt_r7_0x03fc0000[] = {
  0xff, 0x07, 0x57, 0xc3 // cmp gt r7 0x03fc0000
};
const byte kInstruction_cmp_ne_r8_0x000ff000[] = {
  0xff, 0x0a, 0x58, 0x13 // cmp ne r8 0x000ff000
};
const byte kInstruction_cmp_gt_r14_0xc000002a[] = {
  0xab, 0x01, 0x5e, 0xc3 // cmp gt r14 0xc000002a
};
const byte kInstruction_cmp_hi_r12_0x0000ff00[] = {
  0xff, 0x0c, 0x5c, 0x83 // cmp hi r12 0x0000ff00
};
const byte kInstruction_cmp_le_r15_0x00003fc0[] = {
  0xff, 0x0d, 0x5f, 0xd3 // cmp le r15 0x00003fc0
};
const byte kInstruction_cmp_eq_r13_0x000ab000[] = {
  0xab, 0x0a, 0x5d, 0x03 // cmp eq r13 0x000ab000
};
const byte kInstruction_cmp_vc_r7_0x000ab000[] = {
  0xab, 0x0a, 0x57, 0x73 // cmp vc r7 0x000ab000
};
const byte kInstruction_cmp_gt_r7_0xf000000f[] = {
  0xff, 0x02, 0x57, 0xc3 // cmp gt r7 0xf000000f
};
const byte kInstruction_cmp_cc_r6_0xac000002[] = {
  0xab, 0x03, 0x56, 0x33 // cmp cc r6 0xac000002
};
const byte kInstruction_cmp_cs_r14_0x000000ff[] = {
  0xff, 0x00, 0x5e, 0x23 // cmp cs r14 0x000000ff
};
const byte kInstruction_cmp_ne_r2_0x0003fc00[] = {
  0xff, 0x0b, 0x52, 0x13 // cmp ne r2 0x0003fc00
};
const byte kInstruction_cmp_vs_r1_0x002ac000[] = {
  0xab, 0x09, 0x51, 0x63 // cmp vs r1 0x002ac000
};
const byte kInstruction_cmp_eq_r8_0x002ac000[] = {
  0xab, 0x09, 0x58, 0x03 // cmp eq r8 0x002ac000
};
const byte kInstruction_cmp_lt_r8_0x0000ff00[] = {
  0xff, 0x0c, 0x58, 0xb3 // cmp lt r8 0x0000ff00
};
const byte kInstruction_cmp_vs_r9_0xc000003f[] = {
  0xff, 0x01, 0x59, 0x63 // cmp vs r9 0xc000003f
};
const byte kInstruction_cmp_mi_r11_0xff000000[] = {
  0xff, 0x04, 0x5b, 0x43 // cmp mi r11 0xff000000
};
const byte kInstruction_cmp_cs_r12_0x03fc0000[] = {
  0xff, 0x07, 0x5c, 0x23 // cmp cs r12 0x03fc0000
};
const byte kInstruction_cmp_lt_r5_0xc000002a[] = {
  0xab, 0x01, 0x55, 0xb3 // cmp lt r5 0xc000002a
};
const byte kInstruction_cmp_vc_r6_0x000000ab[] = {
  0xab, 0x00, 0x56, 0x73 // cmp vc r6 0x000000ab
};
const byte kInstruction_cmp_ls_r10_0x0ab00000[] = {
  0xab, 0x06, 0x5a, 0x93 // cmp ls r10 0x0ab00000
};
const byte kInstruction_cmp_al_r11_0x00ff0000[] = {
  0xff, 0x08, 0x5b, 0xe3 // cmp al r11 0x00ff0000
};
const byte kInstruction_cmp_hi_r13_0x00000ab0[] = {
  0xab, 0x0e, 0x5d, 0x83 // cmp hi r13 0x00000ab0
};
const byte kInstruction_cmp_ls_r0_0xab000000[] = {
  0xab, 0x04, 0x50, 0x93 // cmp ls r0 0xab000000
};
const byte kInstruction_cmp_le_r5_0xab000000[] = {
  0xab, 0x04, 0x55, 0xd3 // cmp le r5 0xab000000
};
const byte kInstruction_cmp_vs_r4_0x00ff0000[] = {
  0xff, 0x08, 0x54, 0x63 // cmp vs r4 0x00ff0000
};
const byte kInstruction_cmp_al_r10_0x03fc0000[] = {
  0xff, 0x07, 0x5a, 0xe3 // cmp al r10 0x03fc0000
};
const byte kInstruction_cmp_al_r8_0x000003fc[] = {
  0xff, 0x0f, 0x58, 0xe3 // cmp al r8 0x000003fc
};
const byte kInstruction_cmp_vs_r11_0xab000000[] = {
  0xab, 0x04, 0x5b, 0x63 // cmp vs r11 0xab000000
};
const byte kInstruction_cmp_eq_r2_0x00000ff0[] = {
  0xff, 0x0e, 0x52, 0x03 // cmp eq r2 0x00000ff0
};
const byte kInstruction_cmp_vc_r4_0x00000ff0[] = {
  0xff, 0x0e, 0x54, 0x73 // cmp vc r4 0x00000ff0
};
const byte kInstruction_cmp_vc_r9_0x00002ac0[] = {
  0xab, 0x0d, 0x59, 0x73 // cmp vc r9 0x00002ac0
};
const byte kInstruction_cmp_cc_r11_0x00ff0000[] = {
  0xff, 0x08, 0x5b, 0x33 // cmp cc r11 0x00ff0000
};
const byte kInstruction_cmp_cc_r13_0x00ff0000[] = {
  0xff, 0x08, 0x5d, 0x33 // cmp cc r13 0x00ff0000
};
const byte kInstruction_cmp_pl_r0_0x00000ab0[] = {
  0xab, 0x0e, 0x50, 0x53 // cmp pl r0 0x00000ab0
};
const byte kInstruction_cmp_al_r2_0x02ac0000[] = {
  0xab, 0x07, 0x52, 0xe3 // cmp al r2 0x02ac0000
};
const byte kInstruction_cmp_hi_r11_0xc000002a[] = {
  0xab, 0x01, 0x5b, 0x83 // cmp hi r11 0xc000002a
};
const byte kInstruction_cmp_ne_r3_0xf000000f[] = {
  0xff, 0x02, 0x53, 0x13 // cmp ne r3 0xf000000f
};
const byte kInstruction_cmp_cc_r15_0x0ab00000[] = {
  0xab, 0x06, 0x5f, 0x33 // cmp cc r15 0x0ab00000
};
const byte kInstruction_cmp_ge_r12_0x00ff0000[] = {
  0xff, 0x08, 0x5c, 0xa3 // cmp ge r12 0x00ff0000
};
const byte kInstruction_cmp_le_r12_0x002ac000[] = {
  0xab, 0x09, 0x5c, 0xd3 // cmp le r12 0x002ac000
};
const byte kInstruction_cmp_mi_r12_0xc000003f[] = {
  0xff, 0x01, 0x5c, 0x43 // cmp mi r12 0xc000003f
};
const byte kInstruction_cmp_lt_r0_0xfc000003[] = {
  0xff, 0x03, 0x50, 0xb3 // cmp lt r0 0xfc000003
};
const byte kInstruction_cmp_vc_r15_0x000ab000[] = {
  0xab, 0x0a, 0x5f, 0x73 // cmp vc r15 0x000ab000
};
const byte kInstruction_cmp_pl_r5_0x3fc00000[] = {
  0xff, 0x05, 0x55, 0x53 // cmp pl r5 0x3fc00000
};
const byte kInstruction_cmp_vs_r15_0x00ab0000[] = {
  0xab, 0x08, 0x5f, 0x63 // cmp vs r15 0x00ab0000
};
const byte kInstruction_cmp_hi_r3_0x00ff0000[] = {
  0xff, 0x08, 0x53, 0x83 // cmp hi r3 0x00ff0000
};
const byte kInstruction_cmp_lt_r8_0x000000ff[] = {
  0xff, 0x00, 0x58, 0xb3 // cmp lt r8 0x000000ff
};
const byte kInstruction_cmp_le_r2_0x000000ff[] = {
  0xff, 0x00, 0x52, 0xd3 // cmp le r2 0x000000ff
};
const byte kInstruction_cmp_vs_r0_0x0002ac00[] = {
  0xab, 0x0b, 0x50, 0x63 // cmp vs r0 0x0002ac00
};
const byte kInstruction_cmp_vs_r2_0xff000000[] = {
  0xff, 0x04, 0x52, 0x63 // cmp vs r2 0xff000000
};
const byte kInstruction_cmp_pl_r6_0xab000000[] = {
  0xab, 0x04, 0x56, 0x53 // cmp pl r6 0xab000000
};
const byte kInstruction_cmp_ls_r4_0x3fc00000[] = {
  0xff, 0x05, 0x54, 0x93 // cmp ls r4 0x3fc00000
};
const byte kInstruction_cmp_ls_r3_0x000ab000[] = {
  0xab, 0x0a, 0x53, 0x93 // cmp ls r3 0x000ab000
};
const byte kInstruction_cmp_eq_r11_0x000ab000[] = {
  0xab, 0x0a, 0x5b, 0x03 // cmp eq r11 0x000ab000
};
const byte kInstruction_cmp_vc_r6_0x03fc0000[] = {
  0xff, 0x07, 0x56, 0x73 // cmp vc r6 0x03fc0000
};
const byte kInstruction_cmp_mi_r14_0x0000ab00[] = {
  0xab, 0x0c, 0x5e, 0x43 // cmp mi r14 0x0000ab00
};
const byte kInstruction_cmp_pl_r8_0xab000000[] = {
  0xab, 0x04, 0x58, 0x53 // cmp pl r8 0xab000000
};
const byte kInstruction_cmp_pl_r8_0xc000003f[] = {
  0xff, 0x01, 0x58, 0x53 // cmp pl r8 0xc000003f
};
const byte kInstruction_cmp_eq_r14_0x003fc000[] = {
  0xff, 0x09, 0x5e, 0x03 // cmp eq r14 0x003fc000
};
const byte kInstruction_cmp_vs_r9_0x00ff0000[] = {
  0xff, 0x08, 0x59, 0x63 // cmp vs r9 0x00ff0000
};
const byte kInstruction_cmp_vs_r1_0x00002ac0[] = {
  0xab, 0x0d, 0x51, 0x63 // cmp vs r1 0x00002ac0
};
const byte kInstruction_cmp_le_r1_0x00ff0000[] = {
  0xff, 0x08, 0x51, 0xd3 // cmp le r1 0x00ff0000
};
const byte kInstruction_cmp_lt_r7_0x000ff000[] = {
  0xff, 0x0a, 0x57, 0xb3 // cmp lt r7 0x000ff000
};
const byte kInstruction_cmp_mi_r6_0x002ac000[] = {
  0xab, 0x09, 0x56, 0x43 // cmp mi r6 0x002ac000
};
const byte kInstruction_cmp_vc_r11_0xc000003f[] = {
  0xff, 0x01, 0x5b, 0x73 // cmp vc r11 0xc000003f
};
const byte kInstruction_cmp_lt_r4_0x00000000[] = {
  0x00, 0x00, 0x54, 0xb3 // cmp lt r4 0x00000000
};
const byte kInstruction_cmp_pl_r0_0xac000002[] = {
  0xab, 0x03, 0x50, 0x53 // cmp pl r0 0xac000002
};
const byte kInstruction_cmp_ls_r10_0xc000003f[] = {
  0xff, 0x01, 0x5a, 0x93 // cmp ls r10 0xc000003f
};
const byte kInstruction_cmp_cc_r15_0xc000002a[] = {
  0xab, 0x01, 0x5f, 0x33 // cmp cc r15 0xc000002a
};
const TestResult kReferencecmp[] = {
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r10_0x00ab0000),
    kInstruction_cmp_ls_r10_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r13_0xf000000f),
    kInstruction_cmp_ls_r13_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r4_0x00003fc0),
    kInstruction_cmp_pl_r4_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r15_0x00ab0000),
    kInstruction_cmp_ne_r15_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r14_0x002ac000),
    kInstruction_cmp_lt_r14_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r15_0x000000ab),
    kInstruction_cmp_eq_r15_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r6_0x002ac000),
    kInstruction_cmp_al_r6_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_0x0002ac00),
    kInstruction_cmp_pl_r2_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r8_0x00000000),
    kInstruction_cmp_mi_r8_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r13_0x02ac0000),
    kInstruction_cmp_pl_r13_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r9_0xac000002),
    kInstruction_cmp_ge_r9_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_0x000003fc),
    kInstruction_cmp_ne_r3_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r10_0xf000000f),
    kInstruction_cmp_pl_r10_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_0x00003fc0),
    kInstruction_cmp_cc_r0_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_0x002ac000),
    kInstruction_cmp_gt_r6_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r1_0x00ff0000),
    kInstruction_cmp_cs_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r8_0x000002ac),
    kInstruction_cmp_lt_r8_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r4_0x2ac00000),
    kInstruction_cmp_vc_r4_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r11_0x00003fc0),
    kInstruction_cmp_al_r11_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r9_0x000000ab),
    kInstruction_cmp_lt_r9_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r15_0x0000ff00),
    kInstruction_cmp_le_r15_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r9_0xff000000),
    kInstruction_cmp_vc_r9_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_0x0ff00000),
    kInstruction_cmp_ge_r0_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_0x00ff0000),
    kInstruction_cmp_vc_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r12_0x00000ff0),
    kInstruction_cmp_vs_r12_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r13_0x003fc000),
    kInstruction_cmp_pl_r13_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r4_0xff000000),
    kInstruction_cmp_eq_r4_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r12_0xac000002),
    kInstruction_cmp_eq_r12_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r11_0x000000ab),
    kInstruction_cmp_al_r11_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r10_0x00ff0000),
    kInstruction_cmp_ge_r10_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r7_0x0002ac00),
    kInstruction_cmp_vs_r7_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_0x002ac000),
    kInstruction_cmp_le_r7_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r9_0x000003fc),
    kInstruction_cmp_vc_r9_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r14_0x002ac000),
    kInstruction_cmp_vs_r14_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_0x000003fc),
    kInstruction_cmp_vs_r1_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r13_0x3fc00000),
    kInstruction_cmp_le_r13_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r9_0x0002ac00),
    kInstruction_cmp_ne_r9_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r0_0x00ab0000),
    kInstruction_cmp_al_r0_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_0xff000000),
    kInstruction_cmp_hi_r5_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r14_0x000000ab),
    kInstruction_cmp_hi_r14_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r14_0x000003fc),
    kInstruction_cmp_hi_r14_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r14_0x03fc0000),
    kInstruction_cmp_mi_r14_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r8_0x000000ff),
    kInstruction_cmp_mi_r8_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_0x000ab000),
    kInstruction_cmp_gt_r6_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r12_0x0ff00000),
    kInstruction_cmp_mi_r12_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r3_0xff000000),
    kInstruction_cmp_vs_r3_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r7_0x00ab0000),
    kInstruction_cmp_vc_r7_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r6_0x03fc0000),
    kInstruction_cmp_hi_r6_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r5_0x00ab0000),
    kInstruction_cmp_ls_r5_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_0x000002ac),
    kInstruction_cmp_ls_r4_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r13_0x03fc0000),
    kInstruction_cmp_le_r13_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r15_0x002ac000),
    kInstruction_cmp_le_r15_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_0xff000000),
    kInstruction_cmp_pl_r6_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_0x00000ab0),
    kInstruction_cmp_gt_r7_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_0x2ac00000),
    kInstruction_cmp_hi_r3_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r15_0x00000000),
    kInstruction_cmp_gt_r15_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r1_0x002ac000),
    kInstruction_cmp_gt_r1_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r2_0x0000ff00),
    kInstruction_cmp_hi_r2_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r10_0x03fc0000),
    kInstruction_cmp_pl_r10_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r10_0xb000000a),
    kInstruction_cmp_gt_r10_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r10_0x002ac000),
    kInstruction_cmp_ge_r10_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r4_0x0ab00000),
    kInstruction_cmp_al_r4_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r12_0x00000000),
    kInstruction_cmp_ne_r12_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_0x00003fc0),
    kInstruction_cmp_cs_r5_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r6_0x000000ff),
    kInstruction_cmp_cc_r6_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r14_0x03fc0000),
    kInstruction_cmp_hi_r14_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_0xab000000),
    kInstruction_cmp_hi_r3_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r2_0x000ff000),
    kInstruction_cmp_lt_r2_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_0x00ff0000),
    kInstruction_cmp_gt_r3_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r14_0x0ab00000),
    kInstruction_cmp_le_r14_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r13_0x03fc0000),
    kInstruction_cmp_cc_r13_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_0xb000000a),
    kInstruction_cmp_gt_r6_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r3_0x2ac00000),
    kInstruction_cmp_pl_r3_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r15_0x000000ff),
    kInstruction_cmp_mi_r15_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_0x00000ff0),
    kInstruction_cmp_gt_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r4_0x000003fc),
    kInstruction_cmp_ne_r4_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_0x00ff0000),
    kInstruction_cmp_ne_r5_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r7_0x000003fc),
    kInstruction_cmp_ge_r7_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_0x00000000),
    kInstruction_cmp_vs_r5_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r6_0x2ac00000),
    kInstruction_cmp_vs_r6_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_0x3fc00000),
    kInstruction_cmp_mi_r1_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r8_0xc000002a),
    kInstruction_cmp_gt_r8_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r10_0x000000ab),
    kInstruction_cmp_pl_r10_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_0xab000000),
    kInstruction_cmp_mi_r6_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r12_0x3fc00000),
    kInstruction_cmp_ls_r12_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r13_0x03fc0000),
    kInstruction_cmp_vs_r13_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r8_0x00000ab0),
    kInstruction_cmp_eq_r8_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_0x000000ff),
    kInstruction_cmp_gt_r6_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_0x000ab000),
    kInstruction_cmp_vs_r5_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_0x2ac00000),
    kInstruction_cmp_mi_r1_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r6_0x00003fc0),
    kInstruction_cmp_vs_r6_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_0x000002ac),
    kInstruction_cmp_gt_r6_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_0x00000000),
    kInstruction_cmp_eq_r2_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r10_0xc000003f),
    kInstruction_cmp_eq_r10_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r7_0x00ab0000),
    kInstruction_cmp_mi_r7_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_0x2ac00000),
    kInstruction_cmp_cc_r7_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r4_0x00ab0000),
    kInstruction_cmp_pl_r4_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r15_0x00000ff0),
    kInstruction_cmp_ne_r15_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r6_0x02ac0000),
    kInstruction_cmp_al_r6_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_0x000002ac),
    kInstruction_cmp_pl_r6_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r14_0x00ff0000),
    kInstruction_cmp_ne_r14_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_0x0003fc00),
    kInstruction_cmp_ne_r5_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_0x00000ab0),
    kInstruction_cmp_pl_r6_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r10_0x00002ac0),
    kInstruction_cmp_eq_r10_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_0x00000ab0),
    kInstruction_cmp_mi_r4_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r5_0x000ab000),
    kInstruction_cmp_vc_r5_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_0x02ac0000),
    kInstruction_cmp_ge_r0_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r5_0x000002ac),
    kInstruction_cmp_pl_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r13_0x00000ab0),
    kInstruction_cmp_ge_r13_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_0x03fc0000),
    kInstruction_cmp_eq_r2_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r11_0x00000ab0),
    kInstruction_cmp_lt_r11_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r6_0x00000000),
    kInstruction_cmp_ge_r6_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_0xac000002),
    kInstruction_cmp_gt_r2_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r15_0x000000ab),
    kInstruction_cmp_le_r15_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r4_0x00000ff0),
    kInstruction_cmp_cc_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r10_0x02ac0000),
    kInstruction_cmp_pl_r10_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r9_0x00000000),
    kInstruction_cmp_gt_r9_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r8_0x000000ff),
    kInstruction_cmp_vs_r8_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r14_0x0002ac00),
    kInstruction_cmp_gt_r14_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r14_0x00002ac0),
    kInstruction_cmp_vs_r14_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r12_0x00000000),
    kInstruction_cmp_ge_r12_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r8_0xf000000f),
    kInstruction_cmp_vc_r8_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_0x00003fc0),
    kInstruction_cmp_cs_r6_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_0x000003fc),
    kInstruction_cmp_le_r4_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_0x000ff000),
    kInstruction_cmp_cs_r5_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_0x0000ff00),
    kInstruction_cmp_eq_r2_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r10_0x0ab00000),
    kInstruction_cmp_pl_r10_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r11_0xac000002),
    kInstruction_cmp_le_r11_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r15_0x00003fc0),
    kInstruction_cmp_vs_r15_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r2_0x0002ac00),
    kInstruction_cmp_lt_r2_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r1_0x00ab0000),
    kInstruction_cmp_eq_r1_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r7_0x03fc0000),
    kInstruction_cmp_cc_r7_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_0x00000ab0),
    kInstruction_cmp_mi_r6_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r4_0x00000ab0),
    kInstruction_cmp_eq_r4_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_0x0003fc00),
    kInstruction_cmp_ls_r3_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_0x000ab000),
    kInstruction_cmp_mi_r6_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r12_0x003fc000),
    kInstruction_cmp_ne_r12_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r11_0x00ff0000),
    kInstruction_cmp_eq_r11_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r13_0x00ab0000),
    kInstruction_cmp_cs_r13_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_0x000003fc),
    kInstruction_cmp_eq_r5_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r6_0x0003fc00),
    kInstruction_cmp_vs_r6_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r8_0x0ff00000),
    kInstruction_cmp_pl_r8_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r11_0x0000ab00),
    kInstruction_cmp_pl_r11_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_0xac000002),
    kInstruction_cmp_le_r2_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r10_0x000ff000),
    kInstruction_cmp_vc_r10_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r4_0x00000ff0),
    kInstruction_cmp_le_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r12_0x00000ff0),
    kInstruction_cmp_gt_r12_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_0x0002ac00),
    kInstruction_cmp_le_r5_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r0_0xac000002),
    kInstruction_cmp_le_r0_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r11_0x0ff00000),
    kInstruction_cmp_vs_r11_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r0_0x000ab000),
    kInstruction_cmp_ls_r0_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r2_0xf000000f),
    kInstruction_cmp_ls_r2_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_0x0ff00000),
    kInstruction_cmp_cs_r3_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r8_0x0ff00000),
    kInstruction_cmp_hi_r8_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_0x00002ac0),
    kInstruction_cmp_gt_r3_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r15_0xab000000),
    kInstruction_cmp_al_r15_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r13_0x000000ab),
    kInstruction_cmp_eq_r13_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r2_0xc000002a),
    kInstruction_cmp_al_r2_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r13_0x03fc0000),
    kInstruction_cmp_eq_r13_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r3_0x00000ff0),
    kInstruction_cmp_eq_r3_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r12_0x00002ac0),
    kInstruction_cmp_hi_r12_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_0x0ff00000),
    kInstruction_cmp_mi_r2_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r9_0x003fc000),
    kInstruction_cmp_ne_r9_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r14_0x03fc0000),
    kInstruction_cmp_eq_r14_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_0x002ac000),
    kInstruction_cmp_cc_r0_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r14_0x00000ab0),
    kInstruction_cmp_vc_r14_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r15_0xf000000f),
    kInstruction_cmp_mi_r15_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r9_0x000003fc),
    kInstruction_cmp_ge_r9_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r13_0xac000002),
    kInstruction_cmp_vs_r13_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_0x3fc00000),
    kInstruction_cmp_vs_r1_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r12_0x00003fc0),
    kInstruction_cmp_eq_r12_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_0xff000000),
    kInstruction_cmp_mi_r6_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r5_0x000003fc),
    kInstruction_cmp_ne_r5_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r8_0x0ff00000),
    kInstruction_cmp_lt_r8_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r7_0x3fc00000),
    kInstruction_cmp_hi_r7_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r10_0xac000002),
    kInstruction_cmp_ge_r10_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_0x0000ff00),
    kInstruction_cmp_vs_r2_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r6_0x000000ab),
    kInstruction_cmp_al_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r7_0x00ff0000),
    kInstruction_cmp_ge_r7_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r0_0x000ff000),
    kInstruction_cmp_ne_r0_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_0x000000ab),
    kInstruction_cmp_mi_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r1_0xf000000f),
    kInstruction_cmp_hi_r1_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_0x2ac00000),
    kInstruction_cmp_mi_r6_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r11_0x000000ff),
    kInstruction_cmp_vc_r11_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r14_0x02ac0000),
    kInstruction_cmp_ls_r14_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_0x003fc000),
    kInstruction_cmp_ge_r5_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r12_0x0000ab00),
    kInstruction_cmp_ls_r12_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r15_0x00000ab0),
    kInstruction_cmp_cc_r15_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r12_0x0000ab00),
    kInstruction_cmp_vc_r12_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_0xc000002a),
    kInstruction_cmp_vs_r2_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r7_0x0ab00000),
    kInstruction_cmp_lt_r7_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r6_0x00000ff0),
    kInstruction_cmp_ls_r6_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r10_0x000000ff),
    kInstruction_cmp_vc_r10_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_0x0000ab00),
    kInstruction_cmp_ls_r4_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r10_0x003fc000),
    kInstruction_cmp_mi_r10_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r1_0x000002ac),
    kInstruction_cmp_ls_r1_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r7_0xb000000a),
    kInstruction_cmp_ge_r7_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_0xf000000f),
    kInstruction_cmp_gt_r4_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r8_0x002ac000),
    kInstruction_cmp_vc_r8_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_0x0ab00000),
    kInstruction_cmp_eq_r5_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_0xf000000f),
    kInstruction_cmp_gt_r2_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_0xff000000),
    kInstruction_cmp_gt_r6_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r8_0x0ab00000),
    kInstruction_cmp_ls_r8_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r0_0xb000000a),
    kInstruction_cmp_vc_r0_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r6_0x03fc0000),
    kInstruction_cmp_lt_r6_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r10_0x0000ab00),
    kInstruction_cmp_ge_r10_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_0x000ab000),
    kInstruction_cmp_hi_r4_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r11_0x3fc00000),
    kInstruction_cmp_hi_r11_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r12_0xc000003f),
    kInstruction_cmp_vs_r12_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r12_0xb000000a),
    kInstruction_cmp_gt_r12_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r11_0x2ac00000),
    kInstruction_cmp_eq_r11_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r0_0xc000003f),
    kInstruction_cmp_hi_r0_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r12_0xac000002),
    kInstruction_cmp_cs_r12_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r9_0x3fc00000),
    kInstruction_cmp_hi_r9_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_0x00002ac0),
    kInstruction_cmp_vs_r2_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r12_0xb000000a),
    kInstruction_cmp_al_r12_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r12_0x3fc00000),
    kInstruction_cmp_gt_r12_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r6_0xf000000f),
    kInstruction_cmp_gt_r6_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r14_0x000000ff),
    kInstruction_cmp_vc_r14_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r7_0x0002ac00),
    kInstruction_cmp_pl_r7_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_0x03fc0000),
    kInstruction_cmp_ge_r1_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r10_0x0002ac00),
    kInstruction_cmp_hi_r10_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_0x002ac000),
    kInstruction_cmp_gt_r4_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r5_0x000000ff),
    kInstruction_cmp_vc_r5_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r15_0x0000ab00),
    kInstruction_cmp_pl_r15_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r4_0x00ab0000),
    kInstruction_cmp_cc_r4_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r11_0xff000000),
    kInstruction_cmp_pl_r11_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r2_0xf000000f),
    kInstruction_cmp_pl_r2_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r8_0xb000000a),
    kInstruction_cmp_cc_r8_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r13_0x000000ff),
    kInstruction_cmp_al_r13_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_0x000003fc),
    kInstruction_cmp_mi_r6_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r13_0x02ac0000),
    kInstruction_cmp_vs_r13_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r4_0x00ff0000),
    kInstruction_cmp_mi_r4_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_0x000003fc),
    kInstruction_cmp_cs_r3_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r13_0xab000000),
    kInstruction_cmp_pl_r13_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r9_0x002ac000),
    kInstruction_cmp_ls_r9_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r1_0xc000002a),
    kInstruction_cmp_eq_r1_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r12_0x00000000),
    kInstruction_cmp_lt_r12_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r14_0xff000000),
    kInstruction_cmp_ge_r14_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r9_0x002ac000),
    kInstruction_cmp_lt_r9_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r10_0x00000ff0),
    kInstruction_cmp_lt_r10_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_0x000000ff),
    kInstruction_cmp_vs_r5_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r12_0x03fc0000),
    kInstruction_cmp_cc_r12_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r4_0x00000000),
    kInstruction_cmp_ne_r4_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r13_0xff000000),
    kInstruction_cmp_mi_r13_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r7_0x00000ff0),
    kInstruction_cmp_ne_r7_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_0xc000003f),
    kInstruction_cmp_vs_r2_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r5_0x00ff0000),
    kInstruction_cmp_al_r5_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r15_0x00000ff0),
    kInstruction_cmp_hi_r15_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r8_0x00003fc0),
    kInstruction_cmp_ls_r8_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r0_0xff000000),
    kInstruction_cmp_vs_r0_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r6_0x000000ab),
    kInstruction_cmp_vs_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r9_0x00ab0000),
    kInstruction_cmp_cs_r9_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r1_0x0002ac00),
    kInstruction_cmp_hi_r1_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r15_0x2ac00000),
    kInstruction_cmp_hi_r15_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r6_0x0002ac00),
    kInstruction_cmp_hi_r6_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r4_0xc000003f),
    kInstruction_cmp_ge_r4_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r10_0x0000ff00),
    kInstruction_cmp_ls_r10_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r11_0x000003fc),
    kInstruction_cmp_ne_r11_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_0x0002ac00),
    kInstruction_cmp_ls_r3_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r12_0x000003fc),
    kInstruction_cmp_al_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_0xf000000f),
    kInstruction_cmp_le_r7_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r11_0x00000ab0),
    kInstruction_cmp_al_r11_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r13_0x02ac0000),
    kInstruction_cmp_cs_r13_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r1_0x00000ff0),
    kInstruction_cmp_hi_r1_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r11_0x3fc00000),
    kInstruction_cmp_le_r11_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r9_0x000003fc),
    kInstruction_cmp_hi_r9_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r13_0x000002ac),
    kInstruction_cmp_mi_r13_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r12_0x000003fc),
    kInstruction_cmp_lt_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r14_0x00000ab0),
    kInstruction_cmp_lt_r14_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r1_0x3fc00000),
    kInstruction_cmp_gt_r1_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r14_0xb000000a),
    kInstruction_cmp_cc_r14_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_0x000002ac),
    kInstruction_cmp_ge_r0_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r12_0x000003fc),
    kInstruction_cmp_eq_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r13_0x0ab00000),
    kInstruction_cmp_vc_r13_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r10_0x0003fc00),
    kInstruction_cmp_pl_r10_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r7_0x0000ff00),
    kInstruction_cmp_le_r7_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r5_0x0003fc00),
    kInstruction_cmp_eq_r5_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_0xfc000003),
    kInstruction_cmp_pl_r1_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r15_0x000ff000),
    kInstruction_cmp_gt_r15_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r2_0xb000000a),
    kInstruction_cmp_mi_r2_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r8_0x0000ff00),
    kInstruction_cmp_cs_r8_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r8_0x00002ac0),
    kInstruction_cmp_vs_r8_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r5_0x00ab0000),
    kInstruction_cmp_cs_r5_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r3_0x00ab0000),
    kInstruction_cmp_pl_r3_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r5_0x02ac0000),
    kInstruction_cmp_hi_r5_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r9_0x000002ac),
    kInstruction_cmp_cc_r9_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r13_0x0000ab00),
    kInstruction_cmp_ls_r13_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r11_0x00000ab0),
    kInstruction_cmp_pl_r11_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r14_0x3fc00000),
    kInstruction_cmp_ge_r14_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r14_0x0000ab00),
    kInstruction_cmp_al_r14_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r6_0xac000002),
    kInstruction_cmp_lt_r6_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_0x000ff000),
    kInstruction_cmp_vc_r3_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r8_0xfc000003),
    kInstruction_cmp_ne_r8_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_0x000ab000),
    kInstruction_cmp_cs_r6_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r15_0x0002ac00),
    kInstruction_cmp_hi_r15_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_0x00000ff0),
    kInstruction_cmp_pl_r6_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r15_0x03fc0000),
    kInstruction_cmp_hi_r15_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r6_0x0003fc00),
    kInstruction_cmp_cc_r6_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r12_0x000002ac),
    kInstruction_cmp_eq_r12_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r11_0x02ac0000),
    kInstruction_cmp_ls_r11_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r13_0x00ff0000),
    kInstruction_cmp_ge_r13_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_0x0003fc00),
    kInstruction_cmp_lt_r4_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r0_0x0000ab00),
    kInstruction_cmp_mi_r0_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_0x000000ab),
    kInstruction_cmp_lt_r4_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r2_0xc000003f),
    kInstruction_cmp_ls_r2_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_0x000000ab),
    kInstruction_cmp_pl_r1_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r10_0x0000ff00),
    kInstruction_cmp_ne_r10_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r15_0x00000ab0),
    kInstruction_cmp_vc_r15_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r6_0x02ac0000),
    kInstruction_cmp_eq_r6_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r11_0x00000000),
    kInstruction_cmp_cc_r11_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r7_0x002ac000),
    kInstruction_cmp_mi_r7_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r14_0xab000000),
    kInstruction_cmp_hi_r14_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_0x0000ff00),
    kInstruction_cmp_vc_r6_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r5_0x000002ac),
    kInstruction_cmp_al_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r12_0x0002ac00),
    kInstruction_cmp_cc_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r10_0x000000ab),
    kInstruction_cmp_cc_r10_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r5_0x000002ac),
    kInstruction_cmp_gt_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_0x00000000),
    kInstruction_cmp_vc_r3_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r12_0xac000002),
    kInstruction_cmp_gt_r12_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r10_0x00ab0000),
    kInstruction_cmp_al_r10_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r5_0x000ff000),
    kInstruction_cmp_mi_r5_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_0x00000ff0),
    kInstruction_cmp_pl_r1_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r7_0xf000000f),
    kInstruction_cmp_lt_r7_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r14_0x002ac000),
    kInstruction_cmp_ge_r14_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r0_0xac000002),
    kInstruction_cmp_cc_r0_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r2_0x00000ab0),
    kInstruction_cmp_cs_r2_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r0_0x00002ac0),
    kInstruction_cmp_vs_r0_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r10_0x000ab000),
    kInstruction_cmp_le_r10_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r9_0x0003fc00),
    kInstruction_cmp_ge_r9_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r1_0x00003fc0),
    kInstruction_cmp_lt_r1_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r5_0x000000ff),
    kInstruction_cmp_ge_r5_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r11_0x2ac00000),
    kInstruction_cmp_le_r11_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r9_0x002ac000),
    kInstruction_cmp_le_r9_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r12_0xf000000f),
    kInstruction_cmp_hi_r12_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r3_0x02ac0000),
    kInstruction_cmp_lt_r3_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r13_0x2ac00000),
    kInstruction_cmp_al_r13_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r12_0x00000ab0),
    kInstruction_cmp_vs_r12_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_0x3fc00000),
    kInstruction_cmp_gt_r3_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r0_0x2ac00000),
    kInstruction_cmp_gt_r0_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r15_0x000002ac),
    kInstruction_cmp_eq_r15_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r1_0x000ab000),
    kInstruction_cmp_gt_r1_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_0x2ac00000),
    kInstruction_cmp_gt_r2_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r15_0x00ab0000),
    kInstruction_cmp_mi_r15_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_0x000ab000),
    kInstruction_cmp_mi_r1_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r12_0x0ab00000),
    kInstruction_cmp_ge_r12_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r5_0x000000ab),
    kInstruction_cmp_gt_r5_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r4_0x00000000),
    kInstruction_cmp_gt_r4_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r13_0xc000003f),
    kInstruction_cmp_al_r13_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r7_0xff000000),
    kInstruction_cmp_ls_r7_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r0_0x00000ff0),
    kInstruction_cmp_vs_r0_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r9_0x02ac0000),
    kInstruction_cmp_hi_r9_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r1_0xc000002a),
    kInstruction_cmp_cs_r1_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r8_0xf000000f),
    kInstruction_cmp_hi_r8_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r1_0xb000000a),
    kInstruction_cmp_gt_r1_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_0x0002ac00),
    kInstruction_cmp_gt_r2_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r5_0x000000ab),
    kInstruction_cmp_vs_r5_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r12_0x000ff000),
    kInstruction_cmp_cc_r12_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r0_0x00003fc0),
    kInstruction_cmp_ge_r0_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r12_0x00ab0000),
    kInstruction_cmp_ls_r12_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_0x000003fc),
    kInstruction_cmp_vs_r4_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_0x00003fc0),
    kInstruction_cmp_ls_r4_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r9_0xb000000a),
    kInstruction_cmp_eq_r9_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r9_0x2ac00000),
    kInstruction_cmp_cs_r9_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r12_0x0000ff00),
    kInstruction_cmp_vs_r12_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r1_0x0000ff00),
    kInstruction_cmp_vc_r1_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r12_0xff000000),
    kInstruction_cmp_hi_r12_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r12_0x0002ac00),
    kInstruction_cmp_cs_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r11_0x03fc0000),
    kInstruction_cmp_mi_r11_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_0x000ff000),
    kInstruction_cmp_eq_r2_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r6_0x00000ff0),
    kInstruction_cmp_al_r6_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r7_0x000003fc),
    kInstruction_cmp_cs_r7_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r11_0xb000000a),
    kInstruction_cmp_pl_r11_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r15_0x000ff000),
    kInstruction_cmp_ne_r15_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r14_0x00ab0000),
    kInstruction_cmp_mi_r14_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r4_0x0000ff00),
    kInstruction_cmp_hi_r4_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_0x000002ac),
    kInstruction_cmp_ge_r1_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_0xb000000a),
    kInstruction_cmp_gt_r7_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r2_0x00000000),
    kInstruction_cmp_gt_r2_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r2_0xb000000a),
    kInstruction_cmp_cc_r2_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r14_0x000ab000),
    kInstruction_cmp_vs_r14_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r5_0x000002ac),
    kInstruction_cmp_lt_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r13_0x0000ff00),
    kInstruction_cmp_cc_r13_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r15_0x000002ac),
    kInstruction_cmp_hi_r15_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r1_0x00ff0000),
    kInstruction_cmp_ge_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r15_0x00002ac0),
    kInstruction_cmp_lt_r15_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r8_0x000ff000),
    kInstruction_cmp_lt_r8_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r10_0xc000002a),
    kInstruction_cmp_hi_r10_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r12_0x000ab000),
    kInstruction_cmp_eq_r12_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r11_0x00002ac0),
    kInstruction_cmp_vs_r11_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r10_0x000003fc),
    kInstruction_cmp_hi_r10_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r8_0x000003fc),
    kInstruction_cmp_cc_r8_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r11_0x00000ab0),
    kInstruction_cmp_vc_r11_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r3_0xac000002),
    kInstruction_cmp_le_r3_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r11_0xc000002a),
    kInstruction_cmp_cc_r11_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r6_0xab000000),
    kInstruction_cmp_lt_r6_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r1_0x00003fc0),
    kInstruction_cmp_hi_r1_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r3_0x00002ac0),
    kInstruction_cmp_vc_r3_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_0x00000ab0),
    kInstruction_cmp_vc_r6_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r6_0x03fc0000),
    kInstruction_cmp_ls_r6_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r11_0x0ab00000),
    kInstruction_cmp_hi_r11_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r12_0x0002ac00),
    kInstruction_cmp_lt_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r8_0xab000000),
    kInstruction_cmp_al_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_0x00000ab0),
    kInstruction_cmp_vs_r2_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r14_0x02ac0000),
    kInstruction_cmp_hi_r14_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r3_0x00000ff0),
    kInstruction_cmp_cs_r3_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r9_0xb000000a),
    kInstruction_cmp_cc_r9_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r9_0x00000ff0),
    kInstruction_cmp_vc_r9_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r9_0xab000000),
    kInstruction_cmp_ne_r9_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r10_0xb000000a),
    kInstruction_cmp_cc_r10_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r11_0xb000000a),
    kInstruction_cmp_ls_r11_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r11_0x00ff0000),
    kInstruction_cmp_lt_r11_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r3_0x000003fc),
    kInstruction_cmp_lt_r3_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r14_0x00002ac0),
    kInstruction_cmp_gt_r14_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r8_0xc000003f),
    kInstruction_cmp_ls_r8_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r11_0x000ab000),
    kInstruction_cmp_al_r11_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r7_0x000ab000),
    kInstruction_cmp_lt_r7_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r14_0xff000000),
    kInstruction_cmp_vs_r14_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r2_0xab000000),
    kInstruction_cmp_vc_r2_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_0x00000ff0),
    kInstruction_cmp_ne_r3_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r15_0x02ac0000),
    kInstruction_cmp_ne_r15_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r3_0x000ff000),
    kInstruction_cmp_gt_r3_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r1_0x2ac00000),
    kInstruction_cmp_pl_r1_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r1_0x00002ac0),
    kInstruction_cmp_mi_r1_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_0xac000002),
    kInstruction_cmp_vc_r6_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_0x0ff00000),
    kInstruction_cmp_vs_r2_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r2_0x000003fc),
    kInstruction_cmp_ge_r2_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r15_0x0000ff00),
    kInstruction_cmp_cs_r15_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r3_0x000002ac),
    kInstruction_cmp_lt_r3_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r6_0xff000000),
    kInstruction_cmp_cs_r6_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r14_0x000000ff),
    kInstruction_cmp_ge_r14_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_0x03fc0000),
    kInstruction_cmp_gt_r7_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r8_0x000ff000),
    kInstruction_cmp_ne_r8_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r14_0xc000002a),
    kInstruction_cmp_gt_r14_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r12_0x0000ff00),
    kInstruction_cmp_hi_r12_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r15_0x00003fc0),
    kInstruction_cmp_le_r15_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r13_0x000ab000),
    kInstruction_cmp_eq_r13_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r7_0x000ab000),
    kInstruction_cmp_vc_r7_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_gt_r7_0xf000000f),
    kInstruction_cmp_gt_r7_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r6_0xac000002),
    kInstruction_cmp_cc_r6_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r14_0x000000ff),
    kInstruction_cmp_cs_r14_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r2_0x0003fc00),
    kInstruction_cmp_ne_r2_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_0x002ac000),
    kInstruction_cmp_vs_r1_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r8_0x002ac000),
    kInstruction_cmp_eq_r8_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r8_0x0000ff00),
    kInstruction_cmp_lt_r8_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r9_0xc000003f),
    kInstruction_cmp_vs_r9_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r11_0xff000000),
    kInstruction_cmp_mi_r11_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cs_r12_0x03fc0000),
    kInstruction_cmp_cs_r12_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r5_0xc000002a),
    kInstruction_cmp_lt_r5_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_0x000000ab),
    kInstruction_cmp_vc_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r10_0x0ab00000),
    kInstruction_cmp_ls_r10_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r11_0x00ff0000),
    kInstruction_cmp_al_r11_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r13_0x00000ab0),
    kInstruction_cmp_hi_r13_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r0_0xab000000),
    kInstruction_cmp_ls_r0_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r5_0xab000000),
    kInstruction_cmp_le_r5_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r4_0x00ff0000),
    kInstruction_cmp_vs_r4_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r10_0x03fc0000),
    kInstruction_cmp_al_r10_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r8_0x000003fc),
    kInstruction_cmp_al_r8_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r11_0xab000000),
    kInstruction_cmp_vs_r11_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r2_0x00000ff0),
    kInstruction_cmp_eq_r2_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r4_0x00000ff0),
    kInstruction_cmp_vc_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r9_0x00002ac0),
    kInstruction_cmp_vc_r9_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r11_0x00ff0000),
    kInstruction_cmp_cc_r11_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r13_0x00ff0000),
    kInstruction_cmp_cc_r13_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_0x00000ab0),
    kInstruction_cmp_pl_r0_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_al_r2_0x02ac0000),
    kInstruction_cmp_al_r2_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r11_0xc000002a),
    kInstruction_cmp_hi_r11_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ne_r3_0xf000000f),
    kInstruction_cmp_ne_r3_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r15_0x0ab00000),
    kInstruction_cmp_cc_r15_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ge_r12_0x00ff0000),
    kInstruction_cmp_ge_r12_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r12_0x002ac000),
    kInstruction_cmp_le_r12_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r12_0xc000003f),
    kInstruction_cmp_mi_r12_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r0_0xfc000003),
    kInstruction_cmp_lt_r0_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r15_0x000ab000),
    kInstruction_cmp_vc_r15_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r5_0x3fc00000),
    kInstruction_cmp_pl_r5_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r15_0x00ab0000),
    kInstruction_cmp_vs_r15_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_hi_r3_0x00ff0000),
    kInstruction_cmp_hi_r3_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r8_0x000000ff),
    kInstruction_cmp_lt_r8_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r2_0x000000ff),
    kInstruction_cmp_le_r2_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r0_0x0002ac00),
    kInstruction_cmp_vs_r0_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r2_0xff000000),
    kInstruction_cmp_vs_r2_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r6_0xab000000),
    kInstruction_cmp_pl_r6_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r4_0x3fc00000),
    kInstruction_cmp_ls_r4_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r3_0x000ab000),
    kInstruction_cmp_ls_r3_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r11_0x000ab000),
    kInstruction_cmp_eq_r11_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r6_0x03fc0000),
    kInstruction_cmp_vc_r6_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r14_0x0000ab00),
    kInstruction_cmp_mi_r14_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r8_0xab000000),
    kInstruction_cmp_pl_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r8_0xc000003f),
    kInstruction_cmp_pl_r8_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_eq_r14_0x003fc000),
    kInstruction_cmp_eq_r14_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r9_0x00ff0000),
    kInstruction_cmp_vs_r9_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vs_r1_0x00002ac0),
    kInstruction_cmp_vs_r1_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_le_r1_0x00ff0000),
    kInstruction_cmp_le_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r7_0x000ff000),
    kInstruction_cmp_lt_r7_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_mi_r6_0x002ac000),
    kInstruction_cmp_mi_r6_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_vc_r11_0xc000003f),
    kInstruction_cmp_vc_r11_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_lt_r4_0x00000000),
    kInstruction_cmp_lt_r4_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_pl_r0_0xac000002),
    kInstruction_cmp_pl_r0_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_ls_r10_0xc000003f),
    kInstruction_cmp_ls_r10_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_cmp_cc_r15_0xc000002a),
    kInstruction_cmp_cc_r15_0xc000002a,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_OPERAND_CONST_CAN_USE_PC_CMP_A32_H_
